@@ -1,7 +1,7 @@
 var AttributeGroup_8h =
 [
     [ "GroupCodec", "structopenvdb_1_1v12__1_1_1points_1_1GroupCodec.html", "structopenvdb_1_1v12__1_1_1points_1_1GroupCodec" ],
-    [ "GroupCodec::Storage< T >", "structopenvdb_1_1v12__1_1_1points_1_1GroupCodec_1_1Storage.html", "structopenvdb_1_1v12__1_1_1points_1_1GroupCodec_1_1Storage" ],
+    [ "GroupCodec::Storage&lt; T &gt;", "structopenvdb_1_1v12__1_1_1points_1_1GroupCodec_1_1Storage.html", "structopenvdb_1_1v12__1_1_1points_1_1GroupCodec_1_1Storage" ],
     [ "GroupHandle", "classopenvdb_1_1v12__1_1_1points_1_1GroupHandle.html", "classopenvdb_1_1v12__1_1_1points_1_1GroupHandle" ],
     [ "GroupHandle::BitMask", "structopenvdb_1_1v12__1_1_1points_1_1GroupHandle_1_1BitMask.html", null ],
     [ "GroupWriteHandle", "classopenvdb_1_1v12__1_1_1points_1_1GroupWriteHandle.html", "classopenvdb_1_1v12__1_1_1points_1_1GroupWriteHandle" ],
