@@ -2,8 +2,8 @@ var Coord_8h =
 [
     [ "Coord", "classopenvdb_1_1v12__1_1_1math_1_1Coord.html", "classopenvdb_1_1v12__1_1_1math_1_1Coord" ],
     [ "CoordBBox", "classopenvdb_1_1v12__1_1_1math_1_1CoordBBox.html", "classopenvdb_1_1v12__1_1_1math_1_1CoordBBox" ],
-    [ "CoordBBox::Iterator< ZYXOrder >", "classopenvdb_1_1v12__1_1_1math_1_1CoordBBox_1_1Iterator.html", "classopenvdb_1_1v12__1_1_1math_1_1CoordBBox_1_1Iterator" ],
-    [ "hash< openvdb::math::Coord >", "structstd_1_1hash_3_01openvdb_1_1math_1_1Coord_01_4.html", "structstd_1_1hash_3_01openvdb_1_1math_1_1Coord_01_4" ],
+    [ "CoordBBox::Iterator&lt; ZYXOrder &gt;", "classopenvdb_1_1v12__1_1_1math_1_1CoordBBox_1_1Iterator.html", "classopenvdb_1_1v12__1_1_1math_1_1CoordBBox_1_1Iterator" ],
+    [ "hash&lt; openvdb::math::Coord &gt;", "structstd_1_1hash_3_01openvdb_1_1math_1_1Coord_01_4.html", "structstd_1_1hash_3_01openvdb_1_1math_1_1Coord_01_4" ],
     [ "openvdb::v12_1::math::Abs", "namespaceopenvdb_1_1v12__1_1_1math.html#ab80ed0bc25befc6da9cbe9d454fafb8a", null ],
     [ "openvdb::v12_1::math::operator+", "namespaceopenvdb_1_1v12__1_1_1math.html#aa3f0948ec65f4588e7de91305d543863", null ],
     [ "openvdb::v12_1::math::operator+", "namespaceopenvdb_1_1v12__1_1_1math.html#a7d1ab284e3d6045d076087f1a2c10aef", null ],
