@@ -1,6 +1,6 @@
 var Formats_8h =
 [
-    [ "FormattedInt< IntT >", "classopenvdb_1_1v12__1_1_1util_1_1FormattedInt.html", "classopenvdb_1_1v12__1_1_1util_1_1FormattedInt" ],
+    [ "FormattedInt&lt; IntT &gt;", "classopenvdb_1_1v12__1_1_1util_1_1FormattedInt.html", "classopenvdb_1_1v12__1_1_1util_1_1FormattedInt" ],
     [ "openvdb::v12_1::util::formattedInt", "namespaceopenvdb_1_1v12__1_1_1util.html#a10754eb73639cd8e66512456e4b52018", null ],
     [ "openvdb::v12_1::util::operator<<", "namespaceopenvdb_1_1v12__1_1_1util.html#a51264d407b348edb4d167d77e0adbaeb", null ],
     [ "openvdb::v12_1::util::printBytes", "namespaceopenvdb_1_1v12__1_1_1util.html#a73d09743b17b73385ae8ae9128c28b37", null ],
