@@ -1,7 +1,7 @@
 var GU__VDBPointTools_8h =
 [
-    [ "GU_VDBPointList< VectorType >", "structGU__VDBPointList.html", "structGU__VDBPointList" ],
-    [ "IndexToOffsetOp< PointArrayType >", "structGU__VDBPointToolsInternal_1_1IndexToOffsetOp.html", "structGU__VDBPointToolsInternal_1_1IndexToOffsetOp" ],
+    [ "GU_VDBPointList&lt; VectorType &gt;", "structGU__VDBPointList.html", "structGU__VDBPointList" ],
+    [ "IndexToOffsetOp&lt; PointArrayType &gt;", "structGU__VDBPointToolsInternal_1_1IndexToOffsetOp.html", "structGU__VDBPointToolsInternal_1_1IndexToOffsetOp" ],
     [ "PackedMaskConstructor", "structGU__VDBPointToolsInternal_1_1PackedMaskConstructor.html", "structGU__VDBPointToolsInternal_1_1PackedMaskConstructor" ],
     [ "GU_VDBPointToolsInternal::getPackedPrimitiveOffsets", "namespaceGU__VDBPointToolsInternal.html#a7aaa9b5d5e4ab683a4b5455fe6df3970", null ],
     [ "GUvdbConvertIndexToOffset", "GU__VDBPointTools_8h.html#a83e52b9d21520fc21d016f3bcdfdb31c", null ],
