@@ -4,7 +4,7 @@ var GeometryUtil_8h =
     [ "PrimCpyOp", "classopenvdb__houdini_1_1PrimCpyOp.html", "classopenvdb__houdini_1_1PrimCpyOp" ],
     [ "VertexNormalOp", "classopenvdb__houdini_1_1VertexNormalOp.html", "classopenvdb__houdini_1_1VertexNormalOp" ],
     [ "SharpenFeaturesOp", "classopenvdb__houdini_1_1SharpenFeaturesOp.html", "classopenvdb__houdini_1_1SharpenFeaturesOp" ],
-    [ "GenAdaptivityMaskOp< IndexTreeType, BoolTreeType >", "classopenvdb__houdini_1_1GenAdaptivityMaskOp.html", "classopenvdb__houdini_1_1GenAdaptivityMaskOp" ],
+    [ "GenAdaptivityMaskOp&lt; IndexTreeType, BoolTreeType &gt;", "classopenvdb__houdini_1_1GenAdaptivityMaskOp.html", "classopenvdb__houdini_1_1GenAdaptivityMaskOp" ],
     [ "openvdb_houdini::convertGeometry", "namespaceopenvdb__houdini.html#acb937ece5300c73075d3735779fe2d7f", null ],
     [ "openvdb_houdini::convertGeometry", "namespaceopenvdb__houdini.html#a1efb0363450569b28730611e2891f077", null ],
     [ "openvdb_houdini::drawFrustum", "namespaceopenvdb__houdini.html#a8ef60375f1d6abbcec4a1835a5008f55", null ],
