@@ -1,7 +1,7 @@
 var GridHandle_8h =
 [
     [ "GridHandleMetaData", "structnanovdb_1_1GridHandleMetaData.html", "structnanovdb_1_1GridHandleMetaData" ],
-    [ "GridHandle< BufferT >", "classnanovdb_1_1GridHandle.html", "classnanovdb_1_1GridHandle" ],
+    [ "GridHandle&lt; BufferT &gt;", "classnanovdb_1_1GridHandle.html", "classnanovdb_1_1GridHandle" ],
     [ "nanovdb::cpyGridHandleMeta", "namespacenanovdb.html#a0aa7ba290bbd672413524413aae811e7", null ],
     [ "nanovdb::mergeGrids", "namespacenanovdb.html#a1999ea4347f33abf15bb667141a1f2df", null ],
     [ "nanovdb::splitGrids", "namespacenanovdb.html#a2d80d40ab0add4f3ab16c1cdbb50c2ce", null ]
