@@ -4,8 +4,8 @@ var GridTransformer_8h =
     [ "GridTransformer", "classopenvdb_1_1v12__1_1_1tools_1_1GridTransformer.html", "classopenvdb_1_1v12__1_1_1tools_1_1GridTransformer" ],
     [ "GridTransformer::MatrixTransform", "structopenvdb_1_1v12__1_1_1tools_1_1GridTransformer_1_1MatrixTransform.html", "structopenvdb_1_1v12__1_1_1tools_1_1GridTransformer_1_1MatrixTransform" ],
     [ "ABTransform", "classopenvdb_1_1v12__1_1_1tools_1_1ABTransform.html", "classopenvdb_1_1v12__1_1_1tools_1_1ABTransform" ],
-    [ "HalfWidthOp< ValueType >", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp" ],
-    [ "HalfWidthOp< bool >", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp_3_01bool_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp_3_01bool_01_4" ],
+    [ "HalfWidthOp&lt; ValueType &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp" ],
+    [ "HalfWidthOp&lt; bool &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp_3_01bool_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp_3_01bool_01_4" ],
     [ "openvdb::v12_1::tools::local_util::decompose", "namespaceopenvdb_1_1v12__1_1_1tools_1_1local__util.html#a057ba643efc5c61f88797c21c7e753fd", null ],
     [ "openvdb::v12_1::tools::doResampleToMatch", "namespaceopenvdb_1_1v12__1_1_1tools.html#af2c1177d6976c4d235583089b2947ba8", null ],
     [ "openvdb::v12_1::tools::resampleToMatch", "namespaceopenvdb_1_1v12__1_1_1tools.html#af4c63aac5d546c4e73dd5f2e8bf734ca", null ],
