@@ -1,6 +1,6 @@
 var HostBuffer_8h =
 [
-    [ "BufferTraits< BufferT >", "structnanovdb_1_1BufferTraits.html", "structnanovdb_1_1BufferTraits" ],
+    [ "BufferTraits&lt; BufferT &gt;", "structnanovdb_1_1BufferTraits.html", "structnanovdb_1_1BufferTraits" ],
     [ "HostBuffer", "classnanovdb_1_1HostBuffer.html", "classnanovdb_1_1HostBuffer" ],
     [ "HostBuffer::Pool", "structnanovdb_1_1HostBuffer_1_1Pool.html", "structnanovdb_1_1HostBuffer_1_1Pool" ],
     [ "checkPtr", "HostBuffer_8h.html#aff2830fced928188855df8b9366e031f", null ]
