@@ -1,6 +1,6 @@
 var LevelSetSphere_8h =
 [
-    [ "LevelSetSphere< GridT, InterruptT >", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetSphere.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetSphere" ],
+    [ "LevelSetSphere&lt; GridT, InterruptT &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetSphere.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetSphere" ],
     [ "openvdb::v12_1::tools::createLevelSetSphere", "namespaceopenvdb_1_1v12__1_1_1tools.html#a7e88a56fc4d07052e30bbd775dee066e", null ],
     [ "openvdb::v12_1::tools::createLevelSetSphere", "namespaceopenvdb_1_1v12__1_1_1tools.html#a47e7b3c363d0d3a15b5859c4b06e9d8b", null ]
 ];
\ No newline at end of file
