@@ -1,14 +1,14 @@
 var Math_8h =
 [
-    [ "Tolerance< T >", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance.html", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance" ],
-    [ "Tolerance< float >", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance_3_01float_01_4.html", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance_3_01float_01_4" ],
-    [ "Tolerance< double >", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance_3_01double_01_4.html", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance_3_01double_01_4" ],
-    [ "Delta< T >", "structopenvdb_1_1v12__1_1_1math_1_1Delta.html", "structopenvdb_1_1v12__1_1_1math_1_1Delta" ],
-    [ "Delta< float >", "structopenvdb_1_1v12__1_1_1math_1_1Delta_3_01float_01_4.html", "structopenvdb_1_1v12__1_1_1math_1_1Delta_3_01float_01_4" ],
-    [ "Delta< double >", "structopenvdb_1_1v12__1_1_1math_1_1Delta_3_01double_01_4.html", "structopenvdb_1_1v12__1_1_1math_1_1Delta_3_01double_01_4" ],
-    [ "Rand01< FloatType, EngineType >", "classopenvdb_1_1v12__1_1_1math_1_1Rand01.html", "classopenvdb_1_1v12__1_1_1math_1_1Rand01" ],
-    [ "RandInt< IntType, EngineType >", "classopenvdb_1_1v12__1_1_1math_1_1RandInt.html", "classopenvdb_1_1v12__1_1_1math_1_1RandInt" ],
-    [ "promote< S, T, typename >", "structopenvdb_1_1v12__1_1_1math_1_1promote.html", "structopenvdb_1_1v12__1_1_1math_1_1promote" ],
+    [ "Tolerance&lt; T &gt;", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance.html", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance" ],
+    [ "Tolerance&lt; float &gt;", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance_3_01float_01_4.html", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance_3_01float_01_4" ],
+    [ "Tolerance&lt; double &gt;", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance_3_01double_01_4.html", "structopenvdb_1_1v12__1_1_1math_1_1Tolerance_3_01double_01_4" ],
+    [ "Delta&lt; T &gt;", "structopenvdb_1_1v12__1_1_1math_1_1Delta.html", "structopenvdb_1_1v12__1_1_1math_1_1Delta" ],
+    [ "Delta&lt; float &gt;", "structopenvdb_1_1v12__1_1_1math_1_1Delta_3_01float_01_4.html", "structopenvdb_1_1v12__1_1_1math_1_1Delta_3_01float_01_4" ],
+    [ "Delta&lt; double &gt;", "structopenvdb_1_1v12__1_1_1math_1_1Delta_3_01double_01_4.html", "structopenvdb_1_1v12__1_1_1math_1_1Delta_3_01double_01_4" ],
+    [ "Rand01&lt; FloatType, EngineType &gt;", "classopenvdb_1_1v12__1_1_1math_1_1Rand01.html", "classopenvdb_1_1v12__1_1_1math_1_1Rand01" ],
+    [ "RandInt&lt; IntType, EngineType &gt;", "classopenvdb_1_1v12__1_1_1math_1_1RandInt.html", "classopenvdb_1_1v12__1_1_1math_1_1RandInt" ],
+    [ "promote&lt; S, T, typename &gt;", "structopenvdb_1_1v12__1_1_1math_1_1promote.html", "structopenvdb_1_1v12__1_1_1math_1_1promote" ],
     [ "OPENVDB_EXACT_IS_APPROX_EQUAL", "Math_8h.html#a6b253af5feb78da3c382919eb161e94f", null ],
     [ "OPENVDB_IS_POD", "Math_8h.html#a76e004807bfa2a68739ea66b5f88c3ba", null ],
     [ "OPENVDB_NO_FP_EQUALITY_WARNING_BEGIN", "Math_8h.html#aa07e40c3d7f010bcb5c1369f6a78c8b0", null ],
@@ -114,10 +114,10 @@ var Math_8h =
     [ "openvdb::v12_1::math::operator+", "namespaceopenvdb_1_1v12__1_1_1math.html#a88a6aa54c63720df9594a3517ecd726b", null ],
     [ "openvdb::v12_1::math::operator+", "namespaceopenvdb_1_1v12__1_1_1math.html#a8bff25c803dbff9c90e616905d29c650", null ],
     [ "openvdb::v12_1::math::operator+", "namespaceopenvdb_1_1v12__1_1_1math.html#a07b9e0a5ed72cd509e37ce5eb0dfa6c5", null ],
-    [ "openvdb::v12_1::math::pi", "namespaceopenvdb_1_1v12__1_1_1math.html#a4887842da9571c7e50d375c60bcefcb3", null ],
-    [ "openvdb::v12_1::math::pi", "namespaceopenvdb_1_1v12__1_1_1math.html#ab6ed60c09c10eabec4da002a3d00fc00", null ],
-    [ "openvdb::v12_1::math::pi", "namespaceopenvdb_1_1v12__1_1_1math.html#a280f7cfa60524d5b01abdadbe5a2e717", null ],
     [ "openvdb::v12_1::math::pi", "namespaceopenvdb_1_1v12__1_1_1math.html#a9a1f67be1ac8b1ad421b36a82ea4d40c", null ],
+    [ "openvdb::v12_1::math::pi", "namespaceopenvdb_1_1v12__1_1_1math.html#a280f7cfa60524d5b01abdadbe5a2e717", null ],
+    [ "openvdb::v12_1::math::pi", "namespaceopenvdb_1_1v12__1_1_1math.html#ab6ed60c09c10eabec4da002a3d00fc00", null ],
+    [ "openvdb::v12_1::math::pi", "namespaceopenvdb_1_1v12__1_1_1math.html#a4887842da9571c7e50d375c60bcefcb3", null ],
     [ "openvdb::v12_1::math::Pow", "namespaceopenvdb_1_1v12__1_1_1math.html#a71599cea79261eca6ee952ac7fbac0bb", null ],
     [ "openvdb::v12_1::math::Pow", "namespaceopenvdb_1_1v12__1_1_1math.html#a5ec34a0d6a607efce7fb318f54f611f0", null ],
     [ "openvdb::v12_1::math::Pow", "namespaceopenvdb_1_1v12__1_1_1math.html#a492e62d2ad2be900307cd1224c6ec81f", null ],
