@@ -1,6 +1,6 @@
 var MeshToVolume_8h =
 [
-    [ "QuadAndTriangleDataAdapter< PointType, PolygonType >", "structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter.html", "structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter" ],
+    [ "QuadAndTriangleDataAdapter&lt; PointType, PolygonType &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter.html", "structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter" ],
     [ "MeshToVoxelEdgeData", "classopenvdb_1_1v12__1_1_1tools_1_1MeshToVoxelEdgeData.html", "classopenvdb_1_1v12__1_1_1tools_1_1MeshToVoxelEdgeData" ],
     [ "MeshToVoxelEdgeData::EdgeData", "structopenvdb_1_1v12__1_1_1tools_1_1MeshToVoxelEdgeData_1_1EdgeData.html", "structopenvdb_1_1v12__1_1_1tools_1_1MeshToVoxelEdgeData_1_1EdgeData" ],
     [ "MeshToVoxelEdgeData::GenEdgeData", "classopenvdb_1_1v12__1_1_1tools_1_1MeshToVoxelEdgeData_1_1GenEdgeData.html", "classopenvdb_1_1v12__1_1_1tools_1_1MeshToVoxelEdgeData_1_1GenEdgeData" ],
