@@ -11,116 +11,117 @@ var NanoVDB_8h =
     [ "Fp16", "classnanovdb_1_1Fp16.html", null ],
     [ "FpN", "classnanovdb_1_1FpN.html", null ],
     [ "Point", "classnanovdb_1_1Point.html", null ],
-    [ "BuildTraits< T >", "structnanovdb_1_1BuildTraits.html", "structnanovdb_1_1BuildTraits" ],
-    [ "BuildToValueMap< T >", "structnanovdb_1_1BuildToValueMap.html", "structnanovdb_1_1BuildToValueMap" ],
-    [ "BuildToValueMap< ValueIndex >", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4" ],
-    [ "BuildToValueMap< ValueOnIndex >", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4" ],
-    [ "BuildToValueMap< ValueIndexMask >", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4" ],
-    [ "BuildToValueMap< ValueOnIndexMask >", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4" ],
-    [ "BuildToValueMap< ValueMask >", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4" ],
-    [ "BuildToValueMap< Half >", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4" ],
-    [ "BuildToValueMap< Fp4 >", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4" ],
-    [ "BuildToValueMap< Fp8 >", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4" ],
-    [ "BuildToValueMap< Fp16 >", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4" ],
-    [ "BuildToValueMap< FpN >", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4" ],
-    [ "BuildToValueMap< Point >", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4" ],
+    [ "BuildTraits&lt; T &gt;", "structnanovdb_1_1BuildTraits.html", "structnanovdb_1_1BuildTraits" ],
+    [ "BuildToValueMap&lt; T &gt;", "structnanovdb_1_1BuildToValueMap.html", "structnanovdb_1_1BuildToValueMap" ],
+    [ "BuildToValueMap&lt; ValueIndex &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4" ],
+    [ "BuildToValueMap&lt; ValueOnIndex &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4" ],
+    [ "BuildToValueMap&lt; ValueIndexMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4" ],
+    [ "BuildToValueMap&lt; ValueOnIndexMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4" ],
+    [ "BuildToValueMap&lt; ValueMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4" ],
+    [ "BuildToValueMap&lt; Half &gt;", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4" ],
+    [ "BuildToValueMap&lt; Fp4 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4" ],
+    [ "BuildToValueMap&lt; Fp8 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4" ],
+    [ "BuildToValueMap&lt; Fp16 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4" ],
+    [ "BuildToValueMap&lt; FpN &gt;", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4" ],
+    [ "BuildToValueMap&lt; Point &gt;", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4" ],
     [ "Version", "classnanovdb_1_1Version.html", "classnanovdb_1_1Version" ],
-    [ "TensorTraits< T, 0 >", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4" ],
-    [ "TensorTraits< T, 1 >", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4" ],
-    [ "FloatTraits< T, int >", "structnanovdb_1_1FloatTraits.html", "structnanovdb_1_1FloatTraits" ],
-    [ "FloatTraits< T, 8 >", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4.html", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4" ],
-    [ "FloatTraits< bool, 1 >", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4" ],
-    [ "FloatTraits< ValueIndex, 1 >", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4" ],
-    [ "FloatTraits< ValueIndexMask, 1 >", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4" ],
-    [ "FloatTraits< ValueOnIndex, 1 >", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4" ],
-    [ "FloatTraits< ValueOnIndexMask, 1 >", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4" ],
-    [ "FloatTraits< ValueMask, 1 >", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4" ],
-    [ "FloatTraits< Point, 1 >", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4" ],
-    [ "BitArray< 8 >", "structnanovdb_1_1BitArray_3_018_01_4.html", "structnanovdb_1_1BitArray_3_018_01_4" ],
-    [ "BitArray< 16 >", "structnanovdb_1_1BitArray_3_0116_01_4.html", "structnanovdb_1_1BitArray_3_0116_01_4" ],
-    [ "BitArray< 32 >", "structnanovdb_1_1BitArray_3_0132_01_4.html", "structnanovdb_1_1BitArray_3_0132_01_4" ],
-    [ "BitArray< 64 >", "structnanovdb_1_1BitArray_3_0164_01_4.html", "structnanovdb_1_1BitArray_3_0164_01_4" ],
-    [ "BitFlags< N >", "classnanovdb_1_1BitFlags.html", "classnanovdb_1_1BitFlags" ],
-    [ "Mask< LOG2DIM >", "classnanovdb_1_1Mask.html", "classnanovdb_1_1Mask" ],
-    [ "Mask< LOG2DIM >::Iterator< On >", "classnanovdb_1_1Mask_1_1Iterator.html", "classnanovdb_1_1Mask_1_1Iterator" ],
-    [ "Mask< LOG2DIM >::DenseIterator", "classnanovdb_1_1Mask_1_1DenseIterator.html", "classnanovdb_1_1Mask_1_1DenseIterator" ],
+    [ "TensorTraits&lt; T, 0 &gt;", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4" ],
+    [ "TensorTraits&lt; T, 1 &gt;", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4" ],
+    [ "FloatTraits&lt; T, int &gt;", "structnanovdb_1_1FloatTraits.html", "structnanovdb_1_1FloatTraits" ],
+    [ "FloatTraits&lt; T, 8 &gt;", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4.html", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4" ],
+    [ "FloatTraits&lt; bool, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4" ],
+    [ "FloatTraits&lt; ValueIndex, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4" ],
+    [ "FloatTraits&lt; ValueIndexMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4" ],
+    [ "FloatTraits&lt; ValueOnIndex, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4" ],
+    [ "FloatTraits&lt; ValueOnIndexMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4" ],
+    [ "FloatTraits&lt; ValueMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4" ],
+    [ "FloatTraits&lt; Point, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4" ],
+    [ "BitArray&lt; 8 &gt;", "structnanovdb_1_1BitArray_3_018_01_4.html", "structnanovdb_1_1BitArray_3_018_01_4" ],
+    [ "BitArray&lt; 16 &gt;", "structnanovdb_1_1BitArray_3_0116_01_4.html", "structnanovdb_1_1BitArray_3_0116_01_4" ],
+    [ "BitArray&lt; 32 &gt;", "structnanovdb_1_1BitArray_3_0132_01_4.html", "structnanovdb_1_1BitArray_3_0132_01_4" ],
+    [ "BitArray&lt; 64 &gt;", "structnanovdb_1_1BitArray_3_0164_01_4.html", "structnanovdb_1_1BitArray_3_0164_01_4" ],
+    [ "BitFlags&lt; N &gt;", "classnanovdb_1_1BitFlags.html", "classnanovdb_1_1BitFlags" ],
+    [ "Mask&lt; LOG2DIM &gt;", "classnanovdb_1_1Mask.html", "classnanovdb_1_1Mask" ],
+    [ "Mask&lt; LOG2DIM &gt;::Iterator&lt; On &gt;", "classnanovdb_1_1Mask_1_1Iterator.html", "classnanovdb_1_1Mask_1_1Iterator" ],
+    [ "Mask&lt; LOG2DIM &gt;::DenseIterator", "classnanovdb_1_1Mask_1_1DenseIterator.html", "classnanovdb_1_1Mask_1_1DenseIterator" ],
     [ "Map", "structnanovdb_1_1Map.html", "structnanovdb_1_1Map" ],
     [ "GridBlindMetaData", "structnanovdb_1_1GridBlindMetaData.html", "structnanovdb_1_1GridBlindMetaData" ],
-    [ "NodeTrait< GridOrTreeOrRootT, 0 >", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4" ],
-    [ "NodeTrait< const GridOrTreeOrRootT, 0 >", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4" ],
-    [ "NodeTrait< GridOrTreeOrRootT, 1 >", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4" ],
-    [ "NodeTrait< const GridOrTreeOrRootT, 1 >", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4" ],
-    [ "NodeTrait< GridOrTreeOrRootT, 2 >", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4" ],
-    [ "NodeTrait< const GridOrTreeOrRootT, 2 >", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4" ],
-    [ "NodeTrait< GridOrTreeOrRootT, 3 >", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4" ],
-    [ "NodeTrait< const GridOrTreeOrRootT, 3 >", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4" ],
+    [ "NodeTrait&lt; GridOrTreeOrRootT, 0 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4" ],
+    [ "NodeTrait&lt; const GridOrTreeOrRootT, 0 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4" ],
+    [ "NodeTrait&lt; GridOrTreeOrRootT, 1 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4" ],
+    [ "NodeTrait&lt; const GridOrTreeOrRootT, 1 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4" ],
+    [ "NodeTrait&lt; GridOrTreeOrRootT, 2 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4" ],
+    [ "NodeTrait&lt; const GridOrTreeOrRootT, 2 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4" ],
+    [ "NodeTrait&lt; GridOrTreeOrRootT, 3 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4" ],
+    [ "NodeTrait&lt; const GridOrTreeOrRootT, 3 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4" ],
     [ "Checksum", "classnanovdb_1_1Checksum.html", "classnanovdb_1_1Checksum" ],
     [ "GridData", "structnanovdb_1_1GridData.html", "structnanovdb_1_1GridData" ],
-    [ "Grid< TreeT >", "classnanovdb_1_1Grid.html", "classnanovdb_1_1Grid" ],
+    [ "Grid&lt; TreeT &gt;", "classnanovdb_1_1Grid.html", "classnanovdb_1_1Grid" ],
     [ "TreeData", "structnanovdb_1_1TreeData.html", "structnanovdb_1_1TreeData" ],
-    [ "GridTree< GridT >", "structnanovdb_1_1GridTree.html", "structnanovdb_1_1GridTree" ],
-    [ "GridTree< const GridT >", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4.html", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4" ],
-    [ "Tree< RootT >", "classnanovdb_1_1Tree.html", "classnanovdb_1_1Tree" ],
-    [ "RootData< ChildT >", "structnanovdb_1_1RootData.html", "structnanovdb_1_1RootData" ],
-    [ "RootData< ChildT >::Tile", "structnanovdb_1_1RootData_1_1Tile.html", "structnanovdb_1_1RootData_1_1Tile" ],
-    [ "RootData< ChildT >::TileIter< DataT >", "classnanovdb_1_1RootData_1_1TileIter.html", "classnanovdb_1_1RootData_1_1TileIter" ],
-    [ "RootNode< ChildT >", "classnanovdb_1_1RootNode.html", "classnanovdb_1_1RootNode" ],
-    [ "RootNode< ChildT >::BaseIter< RootT >", "classnanovdb_1_1RootNode_1_1BaseIter.html", "classnanovdb_1_1RootNode_1_1BaseIter" ],
-    [ "RootNode< ChildT >::ChildIter< RootT >", "classnanovdb_1_1RootNode_1_1ChildIter.html", "classnanovdb_1_1RootNode_1_1ChildIter" ],
-    [ "RootNode< ChildT >::ValueIter< RootT >", "classnanovdb_1_1RootNode_1_1ValueIter.html", "classnanovdb_1_1RootNode_1_1ValueIter" ],
-    [ "RootNode< ChildT >::ValueOnIter< RootT >", "classnanovdb_1_1RootNode_1_1ValueOnIter.html", "classnanovdb_1_1RootNode_1_1ValueOnIter" ],
-    [ "RootNode< ChildT >::DenseIter< RootT >", "classnanovdb_1_1RootNode_1_1DenseIter.html", "classnanovdb_1_1RootNode_1_1DenseIter" ],
-    [ "InternalData< ChildT, LOG2DIM >", "structnanovdb_1_1InternalData.html", "structnanovdb_1_1InternalData" ],
-    [ "InternalData< ChildT, LOG2DIM >::Tile", "unionnanovdb_1_1InternalData_1_1Tile.html", "unionnanovdb_1_1InternalData_1_1Tile" ],
-    [ "InternalNode< ChildT, Log2Dim >", "classnanovdb_1_1InternalNode.html", "classnanovdb_1_1InternalNode" ],
-    [ "InternalNode< ChildT, Log2Dim >::ChildIter< ParentT >", "classnanovdb_1_1InternalNode_1_1ChildIter.html", "classnanovdb_1_1InternalNode_1_1ChildIter" ],
-    [ "InternalNode< ChildT, Log2Dim >::ValueIterator", "classnanovdb_1_1InternalNode_1_1ValueIterator.html", "classnanovdb_1_1InternalNode_1_1ValueIterator" ],
-    [ "InternalNode< ChildT, Log2Dim >::ValueOnIterator", "classnanovdb_1_1InternalNode_1_1ValueOnIterator.html", "classnanovdb_1_1InternalNode_1_1ValueOnIterator" ],
-    [ "InternalNode< ChildT, Log2Dim >::DenseIterator", "classnanovdb_1_1InternalNode_1_1DenseIterator.html", "classnanovdb_1_1InternalNode_1_1DenseIterator" ],
-    [ "LeafData< ValueT, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData.html", "structnanovdb_1_1LeafData" ],
-    [ "LeafFnBase< CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafFnBase.html", "structnanovdb_1_1LeafFnBase" ],
-    [ "LeafData< Fp4, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< Fp8, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< Fp16, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< FpN, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< bool, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< ValueMask, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafIndexBase< CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafIndexBase.html", "structnanovdb_1_1LeafIndexBase" ],
-    [ "LeafData< ValueIndex, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< ValueOnIndex, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< ValueIndexMask, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< ValueOnIndexMask, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< Point, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafNode< BuildT, CoordT, MaskT, Log2Dim >", "classnanovdb_1_1LeafNode.html", "classnanovdb_1_1LeafNode" ],
-    [ "LeafNode< BuildT, CoordT, MaskT, Log2Dim >::ChildNodeType", "structnanovdb_1_1LeafNode_1_1ChildNodeType.html", "structnanovdb_1_1LeafNode_1_1ChildNodeType" ],
-    [ "LeafNode< BuildT, CoordT, MaskT, Log2Dim >::ValueOnIterator", "classnanovdb_1_1LeafNode_1_1ValueOnIterator.html", "classnanovdb_1_1LeafNode_1_1ValueOnIterator" ],
-    [ "LeafNode< BuildT, CoordT, MaskT, Log2Dim >::ValueOffIterator", "classnanovdb_1_1LeafNode_1_1ValueOffIterator.html", "classnanovdb_1_1LeafNode_1_1ValueOffIterator" ],
-    [ "LeafNode< BuildT, CoordT, MaskT, Log2Dim >::ValueIterator", "classnanovdb_1_1LeafNode_1_1ValueIterator.html", "classnanovdb_1_1LeafNode_1_1ValueIterator" ],
-    [ "NanoNode< BuildT, 0 >", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4" ],
-    [ "NanoNode< BuildT, 1 >", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4" ],
-    [ "NanoNode< BuildT, 2 >", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4" ],
-    [ "NanoNode< BuildT, 3 >", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4" ],
-    [ "ReadAccessor< BuildT, -1, -1, -1 >", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4" ],
-    [ "ReadAccessor< BuildT, LEVEL0, -1, -1 >", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4" ],
-    [ "ReadAccessor< BuildT, LEVEL0, LEVEL1, -1 >", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4" ],
+    [ "GridTree&lt; GridT &gt;", "structnanovdb_1_1GridTree.html", "structnanovdb_1_1GridTree" ],
+    [ "GridTree&lt; const GridT &gt;", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4.html", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4" ],
+    [ "Tree&lt; RootT &gt;", "classnanovdb_1_1Tree.html", "classnanovdb_1_1Tree" ],
+    [ "RootData&lt; ChildT &gt;", "structnanovdb_1_1RootData.html", "structnanovdb_1_1RootData" ],
+    [ "RootData&lt; ChildT &gt;::Tile", "structnanovdb_1_1RootData_1_1Tile.html", "structnanovdb_1_1RootData_1_1Tile" ],
+    [ "RootData&lt; ChildT &gt;::TileIter&lt; DataT &gt;", "classnanovdb_1_1RootData_1_1TileIter.html", "classnanovdb_1_1RootData_1_1TileIter" ],
+    [ "RootNode&lt; ChildT &gt;", "classnanovdb_1_1RootNode.html", "classnanovdb_1_1RootNode" ],
+    [ "RootNode&lt; ChildT &gt;::BaseIter&lt; RootT &gt;", "classnanovdb_1_1RootNode_1_1BaseIter.html", "classnanovdb_1_1RootNode_1_1BaseIter" ],
+    [ "RootNode&lt; ChildT &gt;::ChildIter&lt; RootT &gt;", "classnanovdb_1_1RootNode_1_1ChildIter.html", "classnanovdb_1_1RootNode_1_1ChildIter" ],
+    [ "RootNode&lt; ChildT &gt;::ValueIter&lt; RootT &gt;", "classnanovdb_1_1RootNode_1_1ValueIter.html", "classnanovdb_1_1RootNode_1_1ValueIter" ],
+    [ "RootNode&lt; ChildT &gt;::ValueOnIter&lt; RootT &gt;", "classnanovdb_1_1RootNode_1_1ValueOnIter.html", "classnanovdb_1_1RootNode_1_1ValueOnIter" ],
+    [ "RootNode&lt; ChildT &gt;::DenseIter&lt; RootT &gt;", "classnanovdb_1_1RootNode_1_1DenseIter.html", "classnanovdb_1_1RootNode_1_1DenseIter" ],
+    [ "InternalData&lt; ChildT, LOG2DIM &gt;", "structnanovdb_1_1InternalData.html", "structnanovdb_1_1InternalData" ],
+    [ "InternalData&lt; ChildT, LOG2DIM &gt;::Tile", "unionnanovdb_1_1InternalData_1_1Tile.html", "unionnanovdb_1_1InternalData_1_1Tile" ],
+    [ "InternalNode&lt; ChildT, Log2Dim &gt;", "classnanovdb_1_1InternalNode.html", "classnanovdb_1_1InternalNode" ],
+    [ "InternalNode&lt; ChildT, Log2Dim &gt;::ChildIter&lt; ParentT &gt;", "classnanovdb_1_1InternalNode_1_1ChildIter.html", "classnanovdb_1_1InternalNode_1_1ChildIter" ],
+    [ "InternalNode&lt; ChildT, Log2Dim &gt;::ValueIterator", "classnanovdb_1_1InternalNode_1_1ValueIterator.html", "classnanovdb_1_1InternalNode_1_1ValueIterator" ],
+    [ "InternalNode&lt; ChildT, Log2Dim &gt;::ValueOnIterator", "classnanovdb_1_1InternalNode_1_1ValueOnIterator.html", "classnanovdb_1_1InternalNode_1_1ValueOnIterator" ],
+    [ "InternalNode&lt; ChildT, Log2Dim &gt;::DenseIterator", "classnanovdb_1_1InternalNode_1_1DenseIterator.html", "classnanovdb_1_1InternalNode_1_1DenseIterator" ],
+    [ "LeafData&lt; ValueT, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData.html", "structnanovdb_1_1LeafData" ],
+    [ "LeafFnBase&lt; CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafFnBase.html", "structnanovdb_1_1LeafFnBase" ],
+    [ "LeafData&lt; Fp4, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; Fp8, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; Fp16, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; FpN, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; bool, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; ValueMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafIndexBase&lt; CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafIndexBase.html", "structnanovdb_1_1LeafIndexBase" ],
+    [ "LeafData&lt; ValueIndex, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; ValueOnIndex, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; ValueIndexMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; ValueOnIndexMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; Point, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafNode&lt; BuildT, CoordT, MaskT, Log2Dim &gt;", "classnanovdb_1_1LeafNode.html", "classnanovdb_1_1LeafNode" ],
+    [ "LeafNode&lt; BuildT, CoordT, MaskT, Log2Dim &gt;::ChildNodeType", "structnanovdb_1_1LeafNode_1_1ChildNodeType.html", "structnanovdb_1_1LeafNode_1_1ChildNodeType" ],
+    [ "LeafNode&lt; BuildT, CoordT, MaskT, Log2Dim &gt;::ValueOnIterator", "classnanovdb_1_1LeafNode_1_1ValueOnIterator.html", "classnanovdb_1_1LeafNode_1_1ValueOnIterator" ],
+    [ "LeafNode&lt; BuildT, CoordT, MaskT, Log2Dim &gt;::ValueOffIterator", "classnanovdb_1_1LeafNode_1_1ValueOffIterator.html", "classnanovdb_1_1LeafNode_1_1ValueOffIterator" ],
+    [ "LeafNode&lt; BuildT, CoordT, MaskT, Log2Dim &gt;::ValueIterator", "classnanovdb_1_1LeafNode_1_1ValueIterator.html", "classnanovdb_1_1LeafNode_1_1ValueIterator" ],
+    [ "NanoNode&lt; BuildT, 0 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4" ],
+    [ "NanoNode&lt; BuildT, 1 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4" ],
+    [ "NanoNode&lt; BuildT, 2 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4" ],
+    [ "NanoNode&lt; BuildT, 3 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4" ],
+    [ "ReadAccessor&lt; BuildT, -1, -1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4" ],
+    [ "ReadAccessor&lt; BuildT, LEVEL0, -1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4" ],
+    [ "ReadAccessor&lt; BuildT, LEVEL0, LEVEL1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4" ],
+    [ "ReadAccessor&lt; BuildT, 0, 1, 2 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_010_00_011_00_012_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_010_00_011_00_012_01_4" ],
     [ "GridMetaData", "classnanovdb_1_1GridMetaData.html", "classnanovdb_1_1GridMetaData" ],
-    [ "PointAccessor< AttT, BuildT >", "classnanovdb_1_1PointAccessor.html", "classnanovdb_1_1PointAccessor" ],
-    [ "PointAccessor< AttT, Point >", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4.html", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4" ],
-    [ "ChannelAccessor< ChannelT, IndexT >", "classnanovdb_1_1ChannelAccessor.html", "classnanovdb_1_1ChannelAccessor" ],
+    [ "PointAccessor&lt; AttT, BuildT &gt;", "classnanovdb_1_1PointAccessor.html", "classnanovdb_1_1PointAccessor" ],
+    [ "PointAccessor&lt; AttT, Point &gt;", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4.html", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4" ],
+    [ "ChannelAccessor&lt; ChannelT, IndexT &gt;", "classnanovdb_1_1ChannelAccessor.html", "classnanovdb_1_1ChannelAccessor" ],
     [ "FileHeader", "structnanovdb_1_1io_1_1FileHeader.html", "structnanovdb_1_1io_1_1FileHeader" ],
     [ "FileMetaData", "structnanovdb_1_1io_1_1FileMetaData.html", "structnanovdb_1_1io_1_1FileMetaData" ],
-    [ "GetValue< BuildT >", "structnanovdb_1_1GetValue.html", "structnanovdb_1_1GetValue" ],
-    [ "SetValue< BuildT >", "structnanovdb_1_1SetValue.html", "structnanovdb_1_1SetValue" ],
-    [ "SetVoxel< BuildT >", "structnanovdb_1_1SetVoxel.html", "structnanovdb_1_1SetVoxel" ],
-    [ "GetState< BuildT >", "structnanovdb_1_1GetState.html", "structnanovdb_1_1GetState" ],
-    [ "GetDim< BuildT >", "structnanovdb_1_1GetDim.html", "structnanovdb_1_1GetDim" ],
-    [ "GetLeaf< BuildT >", "structnanovdb_1_1GetLeaf.html", "structnanovdb_1_1GetLeaf" ],
-    [ "GetLower< BuildT >", "structnanovdb_1_1GetLower.html", "structnanovdb_1_1GetLower" ],
-    [ "GetUpper< BuildT >", "structnanovdb_1_1GetUpper.html", "structnanovdb_1_1GetUpper" ],
-    [ "GetTile< BuildT >", "structnanovdb_1_1GetTile.html", "structnanovdb_1_1GetTile" ],
-    [ "ProbeValue< BuildT >", "structnanovdb_1_1ProbeValue.html", "structnanovdb_1_1ProbeValue" ],
-    [ "GetNodeInfo< BuildT >", "structnanovdb_1_1GetNodeInfo.html", "structnanovdb_1_1GetNodeInfo" ],
-    [ "GetNodeInfo< BuildT >::NodeInfo", "structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html", "structnanovdb_1_1GetNodeInfo_1_1NodeInfo" ],
+    [ "GetValue&lt; BuildT &gt;", "structnanovdb_1_1GetValue.html", "structnanovdb_1_1GetValue" ],
+    [ "SetValue&lt; BuildT &gt;", "structnanovdb_1_1SetValue.html", "structnanovdb_1_1SetValue" ],
+    [ "SetVoxel&lt; BuildT &gt;", "structnanovdb_1_1SetVoxel.html", "structnanovdb_1_1SetVoxel" ],
+    [ "GetState&lt; BuildT &gt;", "structnanovdb_1_1GetState.html", "structnanovdb_1_1GetState" ],
+    [ "GetDim&lt; BuildT &gt;", "structnanovdb_1_1GetDim.html", "structnanovdb_1_1GetDim" ],
+    [ "GetLeaf&lt; BuildT &gt;", "structnanovdb_1_1GetLeaf.html", "structnanovdb_1_1GetLeaf" ],
+    [ "GetLower&lt; BuildT &gt;", "structnanovdb_1_1GetLower.html", "structnanovdb_1_1GetLower" ],
+    [ "GetUpper&lt; BuildT &gt;", "structnanovdb_1_1GetUpper.html", "structnanovdb_1_1GetUpper" ],
+    [ "GetTile&lt; BuildT &gt;", "structnanovdb_1_1GetTile.html", "structnanovdb_1_1GetTile" ],
+    [ "ProbeValue&lt; BuildT &gt;", "structnanovdb_1_1ProbeValue.html", "structnanovdb_1_1ProbeValue" ],
+    [ "GetNodeInfo&lt; BuildT &gt;", "structnanovdb_1_1GetNodeInfo.html", "structnanovdb_1_1GetNodeInfo" ],
+    [ "GetNodeInfo&lt; BuildT &gt;::NodeInfo", "structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html", "structnanovdb_1_1GetNodeInfo_1_1NodeInfo" ],
     [ "NANOVDB_ALIGN", "NanoVDB_8h.html#a4f8b26821816e0334dfd79e0cbd39c4d", null ],
     [ "NANOVDB_DATA_ALIGNMENT", "NanoVDB_8h.html#a54db29617e4e954de4af9721a183f789", null ],
     [ "NANOVDB_FPN_BRANCHLESS", "NanoVDB_8h.html#a01604c4a002e700cf39c3c3a2dc2eb5c", null ],
