@@ -1,8 +1,8 @@
 var PointConversion_8h =
 [
-    [ "PointAttributeVector< ValueType >", "classopenvdb_1_1v12__1_1_1points_1_1PointAttributeVector.html", "classopenvdb_1_1v12__1_1_1points_1_1PointAttributeVector" ],
-    [ "ValueTypeTraits< T, typename >", "structopenvdb_1_1v12__1_1_1points_1_1internal_1_1ValueTypeTraits.html", "structopenvdb_1_1v12__1_1_1points_1_1internal_1_1ValueTypeTraits" ],
-    [ "ValueTypeTraits< T, void_t< typename T::value_type > >", "structopenvdb_1_1v12__1_1_1points_1_1internal_1_1ValueTypeTraits_3_01T_00_01void__t_3_01typename_01T_1_1value__type_01_4_01_4.html", "structopenvdb_1_1v12__1_1_1points_1_1internal_1_1ValueTypeTraits_3_01T_00_01void__t_3_01typename_01T_1_1value__type_01_4_01_4" ],
+    [ "PointAttributeVector&lt; ValueType &gt;", "classopenvdb_1_1v12__1_1_1points_1_1PointAttributeVector.html", "classopenvdb_1_1v12__1_1_1points_1_1PointAttributeVector" ],
+    [ "ValueTypeTraits&lt; T, typename &gt;", "structopenvdb_1_1v12__1_1_1points_1_1internal_1_1ValueTypeTraits.html", "structopenvdb_1_1v12__1_1_1points_1_1internal_1_1ValueTypeTraits" ],
+    [ "ValueTypeTraits&lt; T, void_t&lt; typename T::value_type &gt; &gt;", "structopenvdb_1_1v12__1_1_1points_1_1internal_1_1ValueTypeTraits_3_01T_00_01void__t_3_01typename_01T_1_1value__type_01_4_01_4.html", "structopenvdb_1_1v12__1_1_1points_1_1internal_1_1ValueTypeTraits_3_01T_00_01void__t_3_01typename_01T_1_1value__type_01_4_01_4" ],
     [ "openvdb::v12_1::points::internal::void_t", "namespaceopenvdb_1_1v12__1_1_1points_1_1internal.html#ab8ddf9531fc4ac7ce28574db20c8f20e", null ],
     [ "openvdb::v12_1::points::computeVoxelSize", "namespaceopenvdb_1_1v12__1_1_1points.html#a85baad70404957c0b435068440ae1c0f", null ],
     [ "openvdb::v12_1::points::convertPointDataGridAttribute", "namespaceopenvdb_1_1v12__1_1_1points.html#ac91e520838e75f17a4e0a3505c128931", null ],
