@@ -1,7 +1,7 @@
 var PointMask_8h =
 [
     [ "NullDeformer", "structopenvdb_1_1v12__1_1_1points_1_1NullDeformer.html", "structopenvdb_1_1v12__1_1_1points_1_1NullDeformer" ],
-    [ "DeformerTraits< DeformerT >", "structopenvdb_1_1v12__1_1_1points_1_1DeformerTraits.html", "structopenvdb_1_1v12__1_1_1points_1_1DeformerTraits" ],
+    [ "DeformerTraits&lt; DeformerT &gt;", "structopenvdb_1_1v12__1_1_1points_1_1DeformerTraits.html", "structopenvdb_1_1v12__1_1_1points_1_1DeformerTraits" ],
     [ "openvdb::v12_1::points::convertPointsToMask", "namespaceopenvdb_1_1v12__1_1_1points.html#a4c532af9bac4f3e4ee0cbbb45b0f0629", null ],
     [ "openvdb::v12_1::points::convertPointsToMask", "namespaceopenvdb_1_1v12__1_1_1points.html#aedeab297ce588a62f0d22c51c5e1beff", null ],
     [ "openvdb::v12_1::points::convertPointsToMask", "namespaceopenvdb_1_1v12__1_1_1points.html#a3bc4fb5488537e98b49bf52140166947", null ]
