@@ -1,8 +1,8 @@
 var PointRasterizeEllipsoidsSDFImpl_8h =
 [
     [ "EllipseIndicies", "structopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal_1_1EllipseIndicies.html", "structopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal_1_1EllipseIndicies" ],
-    [ "EllipsoidTransfer< SdfT, PositionCodecT, RadiusType, FilterT, CPG >", "structopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal_1_1EllipsoidTransfer.html", "structopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal_1_1EllipsoidTransfer" ],
-    [ "EllipseSurfaceMaskOp< RadiusType, MaskTreeT >", "structopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal_1_1EllipseSurfaceMaskOp.html", "structopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal_1_1EllipseSurfaceMaskOp" ],
+    [ "EllipsoidTransfer&lt; SdfT, PositionCodecT, RadiusType, FilterT, CPG &gt;", "structopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal_1_1EllipsoidTransfer.html", "structopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal_1_1EllipsoidTransfer" ],
+    [ "EllipseSurfaceMaskOp&lt; RadiusType, MaskTreeT &gt;", "structopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal_1_1EllipseSurfaceMaskOp.html", "structopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal_1_1EllipseSurfaceMaskOp" ],
     [ "OPENVDB_ELLIPSOID_KERNEL_MODE", "PointRasterizeEllipsoidsSDFImpl_8h.html#ac886438caaeaa5c1681df55bb9da3ca4", null ],
     [ "openvdb::v12_1::points::rasterize_sdf_internal::calcEllipsoidBoundMax", "namespaceopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal.html#af961a27729b361825f7b5e822d4c3156", null ],
     [ "openvdb::v12_1::points::rasterize_sdf_internal::calcUnitEllipsoidBoundMaxSq", "namespaceopenvdb_1_1v12__1_1_1points_1_1rasterize__sdf__internal.html#ada53cdce0382b469f81b166dded1e818", null ],
