@@ -3,7 +3,7 @@ var PointRasterizeFrustum_8h =
     [ "RasterCamera", "classopenvdb_1_1v12__1_1_1points_1_1RasterCamera.html", "classopenvdb_1_1v12__1_1_1points_1_1RasterCamera" ],
     [ "FrustumRasterizerSettings", "structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerSettings.html", "structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerSettings" ],
     [ "FrustumRasterizerMask", "structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask.html", "structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask" ],
-    [ "FrustumRasterizer< PointDataGridT >", "classopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizer.html", "classopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizer" ],
+    [ "FrustumRasterizer&lt; PointDataGridT &gt;", "classopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizer.html", "classopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizer" ],
     [ "RasterGroups", "structopenvdb_1_1v12__1_1_1points_1_1RasterGroups.html", "structopenvdb_1_1v12__1_1_1points_1_1RasterGroups" ],
     [ "openvdb::v12_1::points::RasterMode", "namespaceopenvdb_1_1v12__1_1_1points.html#ae71b1a4d4abc6a321046036c37ae645e", [
       [ "openvdb::v12_1::points::RasterMode::ACCUMULATE", "namespaceopenvdb_1_1v12__1_1_1points.html#ae71b1a4d4abc6a321046036c37ae645eac5d2a98a2112d89452e04fe14de91b91", null ],
