@@ -1,6 +1,6 @@
 var PotentialFlow_8h =
 [
-    [ "VectorToScalarGrid< VecGridT >", "structopenvdb_1_1v12__1_1_1tools_1_1VectorToScalarGrid.html", "structopenvdb_1_1v12__1_1_1tools_1_1VectorToScalarGrid" ],
+    [ "VectorToScalarGrid&lt; VecGridT &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1VectorToScalarGrid.html", "structopenvdb_1_1v12__1_1_1tools_1_1VectorToScalarGrid" ],
     [ "openvdb::v12_1::tools::computePotentialFlow", "namespaceopenvdb_1_1v12__1_1_1tools.html#acec6a2371219a981e94291a793ba0685", null ],
     [ "openvdb::v12_1::tools::computeScalarPotential", "namespaceopenvdb_1_1v12__1_1_1tools.html#a248e7393549aaba7fcb758f85d6c4e0d", null ],
     [ "openvdb::v12_1::tools::createPotentialFlowMask", "namespaceopenvdb_1_1v12__1_1_1tools.html#a1f99dbe0666280f607a4473ddf15d891", null ],
