@@ -1,8 +1,8 @@
 var Prune_8h =
 [
-    [ "InactivePruneOp< TreeT, TerminationLevel >", "classopenvdb_1_1v12__1_1_1tools_1_1InactivePruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1InactivePruneOp" ],
-    [ "TolerancePruneOp< TreeT, TerminationLevel >", "classopenvdb_1_1v12__1_1_1tools_1_1TolerancePruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1TolerancePruneOp" ],
-    [ "LevelSetPruneOp< TreeT, TerminationLevel >", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetPruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetPruneOp" ],
+    [ "InactivePruneOp&lt; TreeT, TerminationLevel &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1InactivePruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1InactivePruneOp" ],
+    [ "TolerancePruneOp&lt; TreeT, TerminationLevel &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1TolerancePruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1TolerancePruneOp" ],
+    [ "LevelSetPruneOp&lt; TreeT, TerminationLevel &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetPruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetPruneOp" ],
     [ "openvdb::v12_1::tools::prune", "namespaceopenvdb_1_1v12__1_1_1tools.html#a8057e1165c928a37703f90eb9496083c", null ],
     [ "openvdb::v12_1::tools::pruneInactive", "namespaceopenvdb_1_1v12__1_1_1tools.html#ae81e76930df0c635a4e175887352257e", null ],
     [ "openvdb::v12_1::tools::pruneInactiveWithValue", "namespaceopenvdb_1_1v12__1_1_1tools.html#ad68447719ca38904491830b5c1caefa8", null ],
