@@ -1,7 +1,7 @@
 var Tuple_8h =
 [
     [ "Conversion", "structopenvdb_1_1v12__1_1_1math_1_1Conversion.html", null ],
-    [ "Tuple< SIZE, T >", "classopenvdb_1_1v12__1_1_1math_1_1Tuple.html", "classopenvdb_1_1v12__1_1_1math_1_1Tuple" ],
+    [ "Tuple&lt; SIZE, T &gt;", "classopenvdb_1_1v12__1_1_1math_1_1Tuple.html", "classopenvdb_1_1v12__1_1_1math_1_1Tuple" ],
     [ "openvdb::v12_1::math::Abs", "namespaceopenvdb_1_1v12__1_1_1math.html#a16ddf495bdf2bd9f3106e97caec7c640", null ],
     [ "openvdb::v12_1::math::isFinite", "namespaceopenvdb_1_1v12__1_1_1math.html#a172a37fd4a76be4795e0770f36c96089", null ],
     [ "openvdb::v12_1::math::isInfinite", "namespaceopenvdb_1_1v12__1_1_1math.html#a385cf87b105b89c242d10c73001665bf", null ],
