@@ -1,6 +1,6 @@
 var ex__raytrace__fog__volume_2common_8h =
 [
-    [ "RayGenOp< Vec3T >", "structRayGenOp.html", "structRayGenOp" ],
+    [ "RayGenOp&lt; Vec3T &gt;", "structRayGenOp.html", "structRayGenOp" ],
     [ "CompositeOp", "structCompositeOp.html", "structCompositeOp" ],
     [ "_USE_MATH_DEFINES", "ex__raytrace__fog__volume_2common_8h.html#a525335710b53cb064ca56b936120431e", null ],
     [ "CompactBy1", "ex__raytrace__fog__volume_2common_8h.html#abfda35a1bcd08b5a0c08d12d10a1bdd0", null ],
