@@ -4,9 +4,7 @@ var globals_func =
     [ "c", "globals_func_c.html", null ],
     [ "g", "globals_func_g.html", null ],
     [ "h", "globals_func_h.html", null ],
-    [ "i", "globals_func_i.html", null ],
     [ "m", "globals_func_m.html", null ],
-    [ "o", "globals_func_o.html", null ],
     [ "p", "globals_func_p.html", null ],
     [ "r", "globals_func_r.html", null ],
     [ "s", "globals_func_s.html", null ],
