@@ -1,122 +1,123 @@
 var namespacenanovdb =
 [
     [ "io", "namespacenanovdb_1_1io.html", "namespacenanovdb_1_1io" ],
-    [ "tools", "namespacenanovdb_1_1tools.html", "namespacenanovdb_1_1tools" ],
     [ "util", "namespacenanovdb_1_1util.html", "namespacenanovdb_1_1util" ],
-    [ "BitArray", "structnanovdb_1_1BitArray.html", null ],
-    [ "BitArray< 16 >", "structnanovdb_1_1BitArray_3_0116_01_4.html", "structnanovdb_1_1BitArray_3_0116_01_4" ],
-    [ "BitArray< 32 >", "structnanovdb_1_1BitArray_3_0132_01_4.html", "structnanovdb_1_1BitArray_3_0132_01_4" ],
-    [ "BitArray< 64 >", "structnanovdb_1_1BitArray_3_0164_01_4.html", "structnanovdb_1_1BitArray_3_0164_01_4" ],
-    [ "BitArray< 8 >", "structnanovdb_1_1BitArray_3_018_01_4.html", "structnanovdb_1_1BitArray_3_018_01_4" ],
-    [ "BitFlags", "classnanovdb_1_1BitFlags.html", "classnanovdb_1_1BitFlags" ],
+    [ "tools", "namespacenanovdb_1_1tools.html", "namespacenanovdb_1_1tools" ],
+    [ "GridHandleMetaData", "structnanovdb_1_1GridHandleMetaData.html", "structnanovdb_1_1GridHandleMetaData" ],
+    [ "GridHandle", "classnanovdb_1_1GridHandle.html", "classnanovdb_1_1GridHandle" ],
     [ "BufferTraits", "structnanovdb_1_1BufferTraits.html", "structnanovdb_1_1BufferTraits" ],
-    [ "BuildToValueMap", "structnanovdb_1_1BuildToValueMap.html", "structnanovdb_1_1BuildToValueMap" ],
-    [ "BuildToValueMap< Fp16 >", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4" ],
-    [ "BuildToValueMap< Fp4 >", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4" ],
-    [ "BuildToValueMap< Fp8 >", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4" ],
-    [ "BuildToValueMap< FpN >", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4" ],
-    [ "BuildToValueMap< Half >", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4" ],
-    [ "BuildToValueMap< Point >", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4" ],
-    [ "BuildToValueMap< ValueIndex >", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4" ],
-    [ "BuildToValueMap< ValueIndexMask >", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4" ],
-    [ "BuildToValueMap< ValueMask >", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4" ],
-    [ "BuildToValueMap< ValueOnIndex >", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4" ],
-    [ "BuildToValueMap< ValueOnIndexMask >", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4" ],
-    [ "BuildTraits", "structnanovdb_1_1BuildTraits.html", "structnanovdb_1_1BuildTraits" ],
-    [ "ChannelAccessor", "classnanovdb_1_1ChannelAccessor.html", "classnanovdb_1_1ChannelAccessor" ],
-    [ "Checksum", "classnanovdb_1_1Checksum.html", "classnanovdb_1_1Checksum" ],
-    [ "FloatTraits", "structnanovdb_1_1FloatTraits.html", "structnanovdb_1_1FloatTraits" ],
-    [ "FloatTraits< bool, 1 >", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4" ],
-    [ "FloatTraits< Point, 1 >", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4" ],
-    [ "FloatTraits< T, 8 >", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4.html", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4" ],
-    [ "FloatTraits< ValueIndex, 1 >", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4" ],
-    [ "FloatTraits< ValueIndexMask, 1 >", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4" ],
-    [ "FloatTraits< ValueMask, 1 >", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4" ],
-    [ "FloatTraits< ValueOnIndex, 1 >", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4" ],
-    [ "FloatTraits< ValueOnIndexMask, 1 >", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4" ],
-    [ "Fp16", "classnanovdb_1_1Fp16.html", null ],
+    [ "HostBuffer", "classnanovdb_1_1HostBuffer.html", "classnanovdb_1_1HostBuffer" ],
+    [ "ValueIndex", "classnanovdb_1_1ValueIndex.html", null ],
+    [ "ValueOnIndex", "classnanovdb_1_1ValueOnIndex.html", null ],
+    [ "ValueIndexMask", "classnanovdb_1_1ValueIndexMask.html", null ],
+    [ "ValueOnIndexMask", "classnanovdb_1_1ValueOnIndexMask.html", null ],
+    [ "ValueMask", "classnanovdb_1_1ValueMask.html", null ],
+    [ "Half", "classnanovdb_1_1Half.html", null ],
     [ "Fp4", "classnanovdb_1_1Fp4.html", null ],
     [ "Fp8", "classnanovdb_1_1Fp8.html", null ],
+    [ "Fp16", "classnanovdb_1_1Fp16.html", null ],
     [ "FpN", "classnanovdb_1_1FpN.html", null ],
+    [ "Point", "classnanovdb_1_1Point.html", null ],
+    [ "BuildTraits", "structnanovdb_1_1BuildTraits.html", "structnanovdb_1_1BuildTraits" ],
+    [ "BuildToValueMap", "structnanovdb_1_1BuildToValueMap.html", "structnanovdb_1_1BuildToValueMap" ],
+    [ "BuildToValueMap&lt; ValueIndex &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4" ],
+    [ "BuildToValueMap&lt; ValueOnIndex &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4" ],
+    [ "BuildToValueMap&lt; ValueIndexMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4" ],
+    [ "BuildToValueMap&lt; ValueOnIndexMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4" ],
+    [ "BuildToValueMap&lt; ValueMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4" ],
+    [ "BuildToValueMap&lt; Half &gt;", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4" ],
+    [ "BuildToValueMap&lt; Fp4 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4" ],
+    [ "BuildToValueMap&lt; Fp8 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4" ],
+    [ "BuildToValueMap&lt; Fp16 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4" ],
+    [ "BuildToValueMap&lt; FpN &gt;", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4" ],
+    [ "BuildToValueMap&lt; Point &gt;", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4" ],
+    [ "Version", "classnanovdb_1_1Version.html", "classnanovdb_1_1Version" ],
+    [ "TensorTraits", "structnanovdb_1_1TensorTraits.html", null ],
+    [ "TensorTraits&lt; T, 0 &gt;", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4" ],
+    [ "TensorTraits&lt; T, 1 &gt;", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4" ],
+    [ "FloatTraits", "structnanovdb_1_1FloatTraits.html", "structnanovdb_1_1FloatTraits" ],
+    [ "FloatTraits&lt; T, 8 &gt;", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4.html", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4" ],
+    [ "FloatTraits&lt; bool, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4" ],
+    [ "FloatTraits&lt; ValueIndex, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4" ],
+    [ "FloatTraits&lt; ValueIndexMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4" ],
+    [ "FloatTraits&lt; ValueOnIndex, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4" ],
+    [ "FloatTraits&lt; ValueOnIndexMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4" ],
+    [ "FloatTraits&lt; ValueMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4" ],
+    [ "FloatTraits&lt; Point, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4" ],
+    [ "BitArray", "structnanovdb_1_1BitArray.html", null ],
+    [ "BitArray&lt; 8 &gt;", "structnanovdb_1_1BitArray_3_018_01_4.html", "structnanovdb_1_1BitArray_3_018_01_4" ],
+    [ "BitArray&lt; 16 &gt;", "structnanovdb_1_1BitArray_3_0116_01_4.html", "structnanovdb_1_1BitArray_3_0116_01_4" ],
+    [ "BitArray&lt; 32 &gt;", "structnanovdb_1_1BitArray_3_0132_01_4.html", "structnanovdb_1_1BitArray_3_0132_01_4" ],
+    [ "BitArray&lt; 64 &gt;", "structnanovdb_1_1BitArray_3_0164_01_4.html", "structnanovdb_1_1BitArray_3_0164_01_4" ],
+    [ "BitFlags", "classnanovdb_1_1BitFlags.html", "classnanovdb_1_1BitFlags" ],
+    [ "Mask", "classnanovdb_1_1Mask.html", "classnanovdb_1_1Mask" ],
+    [ "Map", "structnanovdb_1_1Map.html", "structnanovdb_1_1Map" ],
+    [ "GridBlindMetaData", "structnanovdb_1_1GridBlindMetaData.html", "structnanovdb_1_1GridBlindMetaData" ],
+    [ "NodeTrait", "structnanovdb_1_1NodeTrait.html", null ],
+    [ "NodeTrait&lt; GridOrTreeOrRootT, 0 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4" ],
+    [ "NodeTrait&lt; const GridOrTreeOrRootT, 0 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4" ],
+    [ "NodeTrait&lt; GridOrTreeOrRootT, 1 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4" ],
+    [ "NodeTrait&lt; const GridOrTreeOrRootT, 1 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4" ],
+    [ "NodeTrait&lt; GridOrTreeOrRootT, 2 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4" ],
+    [ "NodeTrait&lt; const GridOrTreeOrRootT, 2 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4" ],
+    [ "NodeTrait&lt; GridOrTreeOrRootT, 3 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4" ],
+    [ "NodeTrait&lt; const GridOrTreeOrRootT, 3 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4" ],
+    [ "GetValue", "structnanovdb_1_1GetValue.html", "structnanovdb_1_1GetValue" ],
+    [ "SetValue", "structnanovdb_1_1SetValue.html", "structnanovdb_1_1SetValue" ],
+    [ "SetVoxel", "structnanovdb_1_1SetVoxel.html", "structnanovdb_1_1SetVoxel" ],
+    [ "GetState", "structnanovdb_1_1GetState.html", "structnanovdb_1_1GetState" ],
     [ "GetDim", "structnanovdb_1_1GetDim.html", "structnanovdb_1_1GetDim" ],
     [ "GetLeaf", "structnanovdb_1_1GetLeaf.html", "structnanovdb_1_1GetLeaf" ],
-    [ "GetLower", "structnanovdb_1_1GetLower.html", "structnanovdb_1_1GetLower" ],
+    [ "ProbeValue", "structnanovdb_1_1ProbeValue.html", "structnanovdb_1_1ProbeValue" ],
     [ "GetNodeInfo", "structnanovdb_1_1GetNodeInfo.html", "structnanovdb_1_1GetNodeInfo" ],
-    [ "GetState", "structnanovdb_1_1GetState.html", "structnanovdb_1_1GetState" ],
-    [ "GetTile", "structnanovdb_1_1GetTile.html", "structnanovdb_1_1GetTile" ],
-    [ "GetUpper", "structnanovdb_1_1GetUpper.html", "structnanovdb_1_1GetUpper" ],
-    [ "GetValue", "structnanovdb_1_1GetValue.html", "structnanovdb_1_1GetValue" ],
-    [ "Grid", "classnanovdb_1_1Grid.html", "classnanovdb_1_1Grid" ],
-    [ "GridBlindMetaData", "structnanovdb_1_1GridBlindMetaData.html", "structnanovdb_1_1GridBlindMetaData" ],
+    [ "Checksum", "classnanovdb_1_1Checksum.html", "classnanovdb_1_1Checksum" ],
     [ "GridData", "structnanovdb_1_1GridData.html", "structnanovdb_1_1GridData" ],
-    [ "GridHandle", "classnanovdb_1_1GridHandle.html", "classnanovdb_1_1GridHandle" ],
-    [ "GridHandleMetaData", "structnanovdb_1_1GridHandleMetaData.html", "structnanovdb_1_1GridHandleMetaData" ],
-    [ "GridMetaData", "classnanovdb_1_1GridMetaData.html", "classnanovdb_1_1GridMetaData" ],
+    [ "ReadAccessor", "classnanovdb_1_1ReadAccessor.html", null ],
+    [ "Grid", "classnanovdb_1_1Grid.html", "classnanovdb_1_1Grid" ],
+    [ "TreeData", "structnanovdb_1_1TreeData.html", "structnanovdb_1_1TreeData" ],
     [ "GridTree", "structnanovdb_1_1GridTree.html", "structnanovdb_1_1GridTree" ],
-    [ "GridTree< const GridT >", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4.html", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4" ],
-    [ "Half", "classnanovdb_1_1Half.html", null ],
-    [ "HostBuffer", "classnanovdb_1_1HostBuffer.html", "classnanovdb_1_1HostBuffer" ],
+    [ "GridTree&lt; const GridT &gt;", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4.html", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4" ],
+    [ "Tree", "classnanovdb_1_1Tree.html", "classnanovdb_1_1Tree" ],
+    [ "RootData", "structnanovdb_1_1RootData.html", "structnanovdb_1_1RootData" ],
+    [ "RootNode", "classnanovdb_1_1RootNode.html", "classnanovdb_1_1RootNode" ],
     [ "InternalData", "structnanovdb_1_1InternalData.html", "structnanovdb_1_1InternalData" ],
     [ "InternalNode", "classnanovdb_1_1InternalNode.html", "classnanovdb_1_1InternalNode" ],
     [ "LeafData", "structnanovdb_1_1LeafData.html", "structnanovdb_1_1LeafData" ],
-    [ "LeafData< bool, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< Fp16, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< Fp4, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< Fp8, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< FpN, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< Point, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< ValueIndex, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< ValueIndexMask, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< ValueMask, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< ValueOnIndex, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
-    [ "LeafData< ValueOnIndexMask, CoordT, MaskT, LOG2DIM >", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
     [ "LeafFnBase", "structnanovdb_1_1LeafFnBase.html", "structnanovdb_1_1LeafFnBase" ],
+    [ "LeafData&lt; Fp4, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; Fp8, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; Fp16, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; FpN, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; bool, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; ValueMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
     [ "LeafIndexBase", "structnanovdb_1_1LeafIndexBase.html", "structnanovdb_1_1LeafIndexBase" ],
+    [ "LeafData&lt; ValueIndex, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; ValueOnIndex, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; ValueIndexMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; ValueOnIndexMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
+    [ "LeafData&lt; Point, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
     [ "LeafNode", "classnanovdb_1_1LeafNode.html", "classnanovdb_1_1LeafNode" ],
-    [ "Map", "structnanovdb_1_1Map.html", "structnanovdb_1_1Map" ],
-    [ "Mask", "classnanovdb_1_1Mask.html", "classnanovdb_1_1Mask" ],
     [ "NanoNode", "structnanovdb_1_1NanoNode.html", null ],
-    [ "NanoNode< BuildT, 0 >", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4" ],
-    [ "NanoNode< BuildT, 1 >", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4" ],
-    [ "NanoNode< BuildT, 2 >", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4" ],
-    [ "NanoNode< BuildT, 3 >", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4" ],
-    [ "NodeManager", "classnanovdb_1_1NodeManager.html", "classnanovdb_1_1NodeManager" ],
-    [ "NodeManagerData", "structnanovdb_1_1NodeManagerData.html", "structnanovdb_1_1NodeManagerData" ],
-    [ "NodeManagerHandle", "classnanovdb_1_1NodeManagerHandle.html", "classnanovdb_1_1NodeManagerHandle" ],
-    [ "NodeTrait", "structnanovdb_1_1NodeTrait.html", null ],
-    [ "NodeTrait< const GridOrTreeOrRootT, 0 >", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4" ],
-    [ "NodeTrait< const GridOrTreeOrRootT, 1 >", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4" ],
-    [ "NodeTrait< const GridOrTreeOrRootT, 2 >", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4" ],
-    [ "NodeTrait< const GridOrTreeOrRootT, 3 >", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4" ],
-    [ "NodeTrait< GridOrTreeOrRootT, 0 >", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4" ],
-    [ "NodeTrait< GridOrTreeOrRootT, 1 >", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4" ],
-    [ "NodeTrait< GridOrTreeOrRootT, 2 >", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4" ],
-    [ "NodeTrait< GridOrTreeOrRootT, 3 >", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4" ],
-    [ "Point", "classnanovdb_1_1Point.html", null ],
+    [ "NanoNode&lt; BuildT, 0 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4" ],
+    [ "NanoNode&lt; BuildT, 1 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4" ],
+    [ "NanoNode&lt; BuildT, 2 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4" ],
+    [ "NanoNode&lt; BuildT, 3 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4" ],
+    [ "ReadAccessor&lt; BuildT, -1, -1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4" ],
+    [ "ReadAccessor&lt; BuildT, LEVEL0, -1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4" ],
+    [ "ReadAccessor&lt; BuildT, LEVEL0, LEVEL1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4" ],
+    [ "ReadAccessor&lt; BuildT, 0, 1, 2 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_010_00_011_00_012_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_010_00_011_00_012_01_4" ],
+    [ "GridMetaData", "classnanovdb_1_1GridMetaData.html", "classnanovdb_1_1GridMetaData" ],
     [ "PointAccessor", "classnanovdb_1_1PointAccessor.html", "classnanovdb_1_1PointAccessor" ],
-    [ "PointAccessor< AttT, Point >", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4.html", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4" ],
-    [ "ProbeValue", "structnanovdb_1_1ProbeValue.html", "structnanovdb_1_1ProbeValue" ],
+    [ "PointAccessor&lt; AttT, Point &gt;", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4.html", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4" ],
+    [ "ChannelAccessor", "classnanovdb_1_1ChannelAccessor.html", "classnanovdb_1_1ChannelAccessor" ],
+    [ "GetLower", "structnanovdb_1_1GetLower.html", "structnanovdb_1_1GetLower" ],
+    [ "GetUpper", "structnanovdb_1_1GetUpper.html", "structnanovdb_1_1GetUpper" ],
+    [ "GetTile", "structnanovdb_1_1GetTile.html", "structnanovdb_1_1GetTile" ],
+    [ "NodeManager", "classnanovdb_1_1NodeManager.html", "classnanovdb_1_1NodeManager" ],
+    [ "NodeManagerHandle", "classnanovdb_1_1NodeManagerHandle.html", "classnanovdb_1_1NodeManagerHandle" ],
+    [ "NodeManagerData", "structnanovdb_1_1NodeManagerData.html", "structnanovdb_1_1NodeManagerData" ],
     [ "Range", "classnanovdb_1_1Range.html", null ],
-    [ "ReadAccessor", "classnanovdb_1_1ReadAccessor.html", null ],
-    [ "ReadAccessor< BuildT, -1, -1, -1 >", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4" ],
-    [ "ReadAccessor< BuildT, LEVEL0, -1, -1 >", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4" ],
-    [ "ReadAccessor< BuildT, LEVEL0, LEVEL1, -1 >", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4" ],
-    [ "RootData", "structnanovdb_1_1RootData.html", "structnanovdb_1_1RootData" ],
-    [ "RootNode", "classnanovdb_1_1RootNode.html", "classnanovdb_1_1RootNode" ],
-    [ "SetValue", "structnanovdb_1_1SetValue.html", "structnanovdb_1_1SetValue" ],
-    [ "SetVoxel", "structnanovdb_1_1SetVoxel.html", "structnanovdb_1_1SetVoxel" ],
-    [ "TensorTraits", "structnanovdb_1_1TensorTraits.html", null ],
-    [ "TensorTraits< T, 0 >", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4" ],
-    [ "TensorTraits< T, 1 >", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4" ],
     [ "Timer", "classnanovdb_1_1Timer.html", "classnanovdb_1_1Timer" ],
-    [ "Tree", "classnanovdb_1_1Tree.html", "classnanovdb_1_1Tree" ],
-    [ "TreeData", "structnanovdb_1_1TreeData.html", "structnanovdb_1_1TreeData" ],
-    [ "ValueIndex", "classnanovdb_1_1ValueIndex.html", null ],
-    [ "ValueIndexMask", "classnanovdb_1_1ValueIndexMask.html", null ],
-    [ "ValueMask", "classnanovdb_1_1ValueMask.html", null ],
-    [ "ValueOnIndex", "classnanovdb_1_1ValueOnIndex.html", null ],
-    [ "ValueOnIndexMask", "classnanovdb_1_1ValueOnIndexMask.html", null ],
-    [ "Version", "classnanovdb_1_1Version.html", "classnanovdb_1_1Version" ],
     [ "BoolGrid", "namespacenanovdb.html#a44c7484144fab7fb2c436e938e2d87ce", null ],
     [ "BoolTree", "namespacenanovdb.html#ad72af753c2016641acc019c714d77f97", null ],
     [ "DefaultReadAccessor", "namespacenanovdb.html#a119ba501e2785cede6a233e164587646", null ],
