@@ -1,27 +1,27 @@
 var namespaceopenvdb_1_1v12__1_1_1io =
 [
     [ "Archive", "classopenvdb_1_1v12__1_1_1io_1_1Archive.html", "classopenvdb_1_1v12__1_1_1io_1_1Archive" ],
+    [ "MaskCompress", "structopenvdb_1_1v12__1_1_1io_1_1MaskCompress.html", "structopenvdb_1_1v12__1_1_1io_1_1MaskCompress" ],
+    [ "RealToHalf", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf" ],
+    [ "RealToHalf&lt; float &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01float_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01float_01_4" ],
+    [ "RealToHalf&lt; double &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01double_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01double_01_4" ],
+    [ "RealToHalf&lt; Vec2s &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2s_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2s_01_4" ],
+    [ "RealToHalf&lt; Vec2d &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2d_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2d_01_4" ],
+    [ "RealToHalf&lt; Vec3s &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3s_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3s_01_4" ],
+    [ "RealToHalf&lt; Vec3d &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3d_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3d_01_4" ],
+    [ "HalfReader", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader.html", null ],
+    [ "HalfReader&lt; false, T &gt;", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01false_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01false_00_01T_01_4" ],
+    [ "HalfReader&lt; true, T &gt;", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01true_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01true_00_01T_01_4" ],
+    [ "HalfWriter", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter.html", null ],
+    [ "HalfWriter&lt; false, T &gt;", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01false_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01false_00_01T_01_4" ],
+    [ "HalfWriter&lt; true, T &gt;", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01true_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01true_00_01T_01_4" ],
     [ "DelayedLoadMetadata", "classopenvdb_1_1v12__1_1_1io_1_1DelayedLoadMetadata.html", "classopenvdb_1_1v12__1_1_1io_1_1DelayedLoadMetadata" ],
     [ "File", "classopenvdb_1_1v12__1_1_1io_1_1File.html", "classopenvdb_1_1v12__1_1_1io_1_1File" ],
     [ "GridDescriptor", "classopenvdb_1_1v12__1_1_1io_1_1GridDescriptor.html", "classopenvdb_1_1v12__1_1_1io_1_1GridDescriptor" ],
-    [ "HalfReader", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader.html", null ],
-    [ "HalfReader< false, T >", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01false_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01false_00_01T_01_4" ],
-    [ "HalfReader< true, T >", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01true_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01true_00_01T_01_4" ],
-    [ "HalfWriter", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter.html", null ],
-    [ "HalfWriter< false, T >", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01false_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01false_00_01T_01_4" ],
-    [ "HalfWriter< true, T >", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01true_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01true_00_01T_01_4" ],
-    [ "MaskCompress", "structopenvdb_1_1v12__1_1_1io_1_1MaskCompress.html", "structopenvdb_1_1v12__1_1_1io_1_1MaskCompress" ],
+    [ "StreamMetadata", "classopenvdb_1_1v12__1_1_1io_1_1StreamMetadata.html", "classopenvdb_1_1v12__1_1_1io_1_1StreamMetadata" ],
     [ "MultiPass", "structopenvdb_1_1v12__1_1_1io_1_1MultiPass.html", null ],
     [ "Queue", "classopenvdb_1_1v12__1_1_1io_1_1Queue.html", "classopenvdb_1_1v12__1_1_1io_1_1Queue" ],
-    [ "RealToHalf", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf" ],
-    [ "RealToHalf< double >", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01double_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01double_01_4" ],
-    [ "RealToHalf< float >", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01float_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01float_01_4" ],
-    [ "RealToHalf< Vec2d >", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2d_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2d_01_4" ],
-    [ "RealToHalf< Vec2s >", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2s_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2s_01_4" ],
-    [ "RealToHalf< Vec3d >", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3d_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3d_01_4" ],
-    [ "RealToHalf< Vec3s >", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3s_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3s_01_4" ],
     [ "Stream", "classopenvdb_1_1v12__1_1_1io_1_1Stream.html", "classopenvdb_1_1v12__1_1_1io_1_1Stream" ],
-    [ "StreamMetadata", "classopenvdb_1_1v12__1_1_1io_1_1StreamMetadata.html", "classopenvdb_1_1v12__1_1_1io_1_1StreamMetadata" ],
     [ "bloscFromStream", "namespaceopenvdb_1_1v12__1_1_1io.html#adfd249ead2665218332388cc9300f4ea", null ],
     [ "bloscToStream", "namespaceopenvdb_1_1v12__1_1_1io.html#a991bbbdbdb7796b490bb386dd914b2bd", null ],
     [ "bloscToStreamSize", "namespaceopenvdb_1_1v12__1_1_1io.html#a86c986c431d1f36ad85d55b306898013", null ],
