@@ -2,12 +2,12 @@ var namespaceopenvdb_1_1v12__1_1_1tools =
 [
     [ "composite", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html", [
       [ "divide", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a0270398d6d5406bfa43d844c342ebe5f", null ],
-      [ "divide", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a94403d4d334f702a068b75842bdd8cf5", null ],
       [ "divide", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#ac3d1a5421a7e04d9eaca81d3e0b83407", null ],
-      [ "max", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a4f31bc8f32de5f0afa35e0588a6c5907", null ],
+      [ "divide", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a94403d4d334f702a068b75842bdd8cf5", null ],
       [ "max", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a6d03d215cbfd2a472d36e7b5cabc0c34", null ],
-      [ "min", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#ad715de018c1beeec76eec91e8d4828c0", null ],
-      [ "min", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a85157a8c619fa7fd8873039785a8e9c7", null ]
+      [ "max", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a4f31bc8f32de5f0afa35e0588a6c5907", null ],
+      [ "min", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a85157a8c619fa7fd8873039785a8e9c7", null ],
+      [ "min", "namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#ad715de018c1beeec76eec91e8d4828c0", null ]
     ] ],
     [ "ds", "namespaceopenvdb_1_1v12__1_1_1tools_1_1ds.html", "namespaceopenvdb_1_1v12__1_1_1tools_1_1ds" ],
     [ "gridop", "namespaceopenvdb_1_1v12__1_1_1tools_1_1gridop.html", "namespaceopenvdb_1_1v12__1_1_1tools_1_1gridop" ],
@@ -25,9 +25,9 @@ var namespaceopenvdb_1_1v12__1_1_1tools =
         [ "kAll", "namespaceopenvdb_1_1v12__1_1_1tools_1_1lstrack.html#a0cd3ac7af16f5e4848317aea237d1baca34bdbffdb1c0e1b603f58fc0d49548b6", null ]
       ] ]
     ] ],
-    [ "lvlset", "namespaceopenvdb_1_1v12__1_1_1tools_1_1lvlset.html", "namespaceopenvdb_1_1v12__1_1_1tools_1_1lvlset" ],
     [ "morphology", "namespaceopenvdb_1_1v12__1_1_1tools_1_1morphology.html", "namespaceopenvdb_1_1v12__1_1_1tools_1_1morphology" ],
     [ "poisson", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson" ],
+    [ "valxform", "namespaceopenvdb_1_1v12__1_1_1tools_1_1valxform.html", "namespaceopenvdb_1_1v12__1_1_1tools_1_1valxform" ],
     [ "Scheme", "namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html", [
       [ "Limiter", "namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a28fd66b0310514194a2fb1d2473e3e29", [
         [ "NO_LIMITER", "namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a28fd66b0310514194a2fb1d2473e3e29a8190f53535f0dc8d9246fdf493756e93", null ],
@@ -43,139 +43,139 @@ var namespaceopenvdb_1_1v12__1_1_1tools =
         [ "BFECC", "namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a4010e0b09fbf6a975c479833d3001f42abe1f8538e8f5da855c0ec4c01b584099", null ]
       ] ]
     ] ],
-    [ "valxform", "namespaceopenvdb_1_1v12__1_1_1tools_1_1valxform.html", "namespaceopenvdb_1_1v12__1_1_1tools_1_1valxform" ],
-    [ "ABTransform", "classopenvdb_1_1v12__1_1_1tools_1_1ABTransform.html", "classopenvdb_1_1v12__1_1_1tools_1_1ABTransform" ],
-    [ "AlphaMask", "classopenvdb_1_1v12__1_1_1tools_1_1AlphaMask.html", "classopenvdb_1_1v12__1_1_1tools_1_1AlphaMask" ],
-    [ "BaseCamera", "classopenvdb_1_1v12__1_1_1tools_1_1BaseCamera.html", "classopenvdb_1_1v12__1_1_1tools_1_1BaseCamera" ],
-    [ "BasePointScatter", "classopenvdb_1_1v12__1_1_1tools_1_1BasePointScatter.html", "classopenvdb_1_1v12__1_1_1tools_1_1BasePointScatter" ],
-    [ "BaseShader", "classopenvdb_1_1v12__1_1_1tools_1_1BaseShader.html", "classopenvdb_1_1v12__1_1_1tools_1_1BaseShader" ],
-    [ "BoxSampler", "structopenvdb_1_1v12__1_1_1tools_1_1BoxSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1BoxSampler" ],
+    [ "lvlset", "namespaceopenvdb_1_1v12__1_1_1tools_1_1lvlset.html", "namespaceopenvdb_1_1v12__1_1_1tools_1_1lvlset" ],
     [ "ChangeBackgroundOp", "classopenvdb_1_1v12__1_1_1tools_1_1ChangeBackgroundOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1ChangeBackgroundOp" ],
     [ "ChangeLevelSetBackgroundOp", "classopenvdb_1_1v12__1_1_1tools_1_1ChangeLevelSetBackgroundOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1ChangeLevelSetBackgroundOp" ],
-    [ "CheckDivergence", "structopenvdb_1_1v12__1_1_1tools_1_1CheckDivergence.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckDivergence" ],
-    [ "CheckEikonal", "structopenvdb_1_1v12__1_1_1tools_1_1CheckEikonal.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckEikonal" ],
-    [ "CheckFinite", "structopenvdb_1_1v12__1_1_1tools_1_1CheckFinite.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckFinite" ],
-    [ "CheckFogVolume", "classopenvdb_1_1v12__1_1_1tools_1_1CheckFogVolume.html", "classopenvdb_1_1v12__1_1_1tools_1_1CheckFogVolume" ],
-    [ "CheckInf", "structopenvdb_1_1v12__1_1_1tools_1_1CheckInf.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckInf" ],
-    [ "CheckLevelSet", "classopenvdb_1_1v12__1_1_1tools_1_1CheckLevelSet.html", "classopenvdb_1_1v12__1_1_1tools_1_1CheckLevelSet" ],
-    [ "CheckMagnitude", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMagnitude.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMagnitude" ],
-    [ "CheckMax", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMax.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMax" ],
-    [ "CheckMin", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMin.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMin" ],
-    [ "CheckNan", "structopenvdb_1_1v12__1_1_1tools_1_1CheckNan.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckNan" ],
-    [ "CheckNormGrad", "structopenvdb_1_1v12__1_1_1tools_1_1CheckNormGrad.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckNormGrad" ],
-    [ "CheckRange", "structopenvdb_1_1v12__1_1_1tools_1_1CheckRange.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckRange" ],
-    [ "ClosestPointProjector", "classopenvdb_1_1v12__1_1_1tools_1_1ClosestPointProjector.html", "classopenvdb_1_1v12__1_1_1tools_1_1ClosestPointProjector" ],
-    [ "ClosestSurfacePoint", "classopenvdb_1_1v12__1_1_1tools_1_1ClosestSurfacePoint.html", "classopenvdb_1_1v12__1_1_1tools_1_1ClosestSurfacePoint" ],
     [ "CompReplaceOp", "structopenvdb_1_1v12__1_1_1tools_1_1CompReplaceOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1CompReplaceOp" ],
-    [ "ConstrainedPointAdvect", "classopenvdb_1_1v12__1_1_1tools_1_1ConstrainedPointAdvect.html", "classopenvdb_1_1v12__1_1_1tools_1_1ConstrainedPointAdvect" ],
-    [ "ContiguousOp", "structopenvdb_1_1v12__1_1_1tools_1_1ContiguousOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1ContiguousOp" ],
-    [ "ConvexVoxelizer", "classopenvdb_1_1v12__1_1_1tools_1_1ConvexVoxelizer.html", "classopenvdb_1_1v12__1_1_1tools_1_1ConvexVoxelizer" ],
-    [ "CopyFromDense", "classopenvdb_1_1v12__1_1_1tools_1_1CopyFromDense.html", "classopenvdb_1_1v12__1_1_1tools_1_1CopyFromDense" ],
-    [ "CopyToDense", "classopenvdb_1_1v12__1_1_1tools_1_1CopyToDense.html", "classopenvdb_1_1v12__1_1_1tools_1_1CopyToDense" ],
-    [ "Cpt", "classopenvdb_1_1v12__1_1_1tools_1_1Cpt.html", "classopenvdb_1_1v12__1_1_1tools_1_1Cpt" ],
-    [ "CsgDifferenceOp", "structopenvdb_1_1v12__1_1_1tools_1_1CsgDifferenceOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1CsgDifferenceOp" ],
-    [ "CsgUnionOrIntersectionOp", "structopenvdb_1_1v12__1_1_1tools_1_1CsgUnionOrIntersectionOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1CsgUnionOrIntersectionOp" ],
-    [ "Curl", "classopenvdb_1_1v12__1_1_1tools_1_1Curl.html", "classopenvdb_1_1v12__1_1_1tools_1_1Curl" ],
-    [ "Dense", "classopenvdb_1_1v12__1_1_1tools_1_1Dense.html", "classopenvdb_1_1v12__1_1_1tools_1_1Dense" ],
     [ "DenseBase", "classopenvdb_1_1v12__1_1_1tools_1_1DenseBase.html", null ],
-    [ "DenseBase< ValueT, LayoutXYZ >", "classopenvdb_1_1v12__1_1_1tools_1_1DenseBase_3_01ValueT_00_01LayoutXYZ_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1DenseBase_3_01ValueT_00_01LayoutXYZ_01_4" ],
-    [ "DenseBase< ValueT, LayoutZYX >", "classopenvdb_1_1v12__1_1_1tools_1_1DenseBase_3_01ValueT_00_01LayoutZYX_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1DenseBase_3_01ValueT_00_01LayoutZYX_01_4" ],
-    [ "DenseTransformer", "classopenvdb_1_1v12__1_1_1tools_1_1DenseTransformer.html", "classopenvdb_1_1v12__1_1_1tools_1_1DenseTransformer" ],
-    [ "DenseUniformPointScatter", "classopenvdb_1_1v12__1_1_1tools_1_1DenseUniformPointScatter.html", "classopenvdb_1_1v12__1_1_1tools_1_1DenseUniformPointScatter" ],
-    [ "DepthFirstNodeVisitor", "structopenvdb_1_1v12__1_1_1tools_1_1DepthFirstNodeVisitor.html", "structopenvdb_1_1v12__1_1_1tools_1_1DepthFirstNodeVisitor" ],
-    [ "DepthFirstNodeVisitor< NodeT, 0 >", "structopenvdb_1_1v12__1_1_1tools_1_1DepthFirstNodeVisitor_3_01NodeT_00_010_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1DepthFirstNodeVisitor_3_01NodeT_00_010_01_4" ],
-    [ "Diagnose", "classopenvdb_1_1v12__1_1_1tools_1_1Diagnose.html", "classopenvdb_1_1v12__1_1_1tools_1_1Diagnose" ],
-    [ "DiffuseShader", "classopenvdb_1_1v12__1_1_1tools_1_1DiffuseShader.html", "classopenvdb_1_1v12__1_1_1tools_1_1DiffuseShader" ],
-    [ "DiffuseShader< Film::RGBA, SamplerType >", "classopenvdb_1_1v12__1_1_1tools_1_1DiffuseShader_3_01Film_1_1RGBA_00_01SamplerType_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1DiffuseShader_3_01Film_1_1RGBA_00_01SamplerType_01_4" ],
-    [ "DiracDelta", "classopenvdb_1_1v12__1_1_1tools_1_1DiracDelta.html", "classopenvdb_1_1v12__1_1_1tools_1_1DiracDelta" ],
-    [ "DiscreteField", "classopenvdb_1_1v12__1_1_1tools_1_1DiscreteField.html", "classopenvdb_1_1v12__1_1_1tools_1_1DiscreteField" ],
-    [ "Divergence", "classopenvdb_1_1v12__1_1_1tools_1_1Divergence.html", "classopenvdb_1_1v12__1_1_1tools_1_1Divergence" ],
+    [ "DenseBase&lt; ValueT, LayoutZYX &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1DenseBase_3_01ValueT_00_01LayoutZYX_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1DenseBase_3_01ValueT_00_01LayoutZYX_01_4" ],
+    [ "DenseBase&lt; ValueT, LayoutXYZ &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1DenseBase_3_01ValueT_00_01LayoutXYZ_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1DenseBase_3_01ValueT_00_01LayoutXYZ_01_4" ],
+    [ "Dense", "classopenvdb_1_1v12__1_1_1tools_1_1Dense.html", "classopenvdb_1_1v12__1_1_1tools_1_1Dense" ],
+    [ "CopyToDense", "classopenvdb_1_1v12__1_1_1tools_1_1CopyToDense.html", "classopenvdb_1_1v12__1_1_1tools_1_1CopyToDense" ],
+    [ "CopyFromDense", "classopenvdb_1_1v12__1_1_1tools_1_1CopyFromDense.html", "classopenvdb_1_1v12__1_1_1tools_1_1CopyFromDense" ],
     [ "DSConverter", "structopenvdb_1_1v12__1_1_1tools_1_1DSConverter.html", "structopenvdb_1_1v12__1_1_1tools_1_1DSConverter" ],
-    [ "DualGridSampler", "classopenvdb_1_1v12__1_1_1tools_1_1DualGridSampler.html", "classopenvdb_1_1v12__1_1_1tools_1_1DualGridSampler" ],
-    [ "DualGridSampler< tree::ValueAccessor< TreeT >, SamplerT >", "classopenvdb_1_1v12__1_1_1tools_1_1DualGridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerT_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1DualGridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerT_01_4" ],
-    [ "EnrightField", "classopenvdb_1_1v12__1_1_1tools_1_1EnrightField.html", "classopenvdb_1_1v12__1_1_1tools_1_1EnrightField" ],
+    [ "SparseExtractor", "classopenvdb_1_1v12__1_1_1tools_1_1SparseExtractor.html", "classopenvdb_1_1v12__1_1_1tools_1_1SparseExtractor" ],
+    [ "SparseMaskedExtractor", "classopenvdb_1_1v12__1_1_1tools_1_1SparseMaskedExtractor.html", "classopenvdb_1_1v12__1_1_1tools_1_1SparseMaskedExtractor" ],
     [ "ExtractAll", "structopenvdb_1_1v12__1_1_1tools_1_1ExtractAll.html", "structopenvdb_1_1v12__1_1_1tools_1_1ExtractAll" ],
+    [ "DenseTransformer", "classopenvdb_1_1v12__1_1_1tools_1_1DenseTransformer.html", "classopenvdb_1_1v12__1_1_1tools_1_1DenseTransformer" ],
+    [ "ContiguousOp", "structopenvdb_1_1v12__1_1_1tools_1_1ContiguousOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1ContiguousOp" ],
+    [ "SparseToDenseCompositor", "classopenvdb_1_1v12__1_1_1tools_1_1SparseToDenseCompositor.html", "classopenvdb_1_1v12__1_1_1tools_1_1SparseToDenseCompositor" ],
+    [ "CheckNan", "structopenvdb_1_1v12__1_1_1tools_1_1CheckNan.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckNan" ],
+    [ "CheckInf", "structopenvdb_1_1v12__1_1_1tools_1_1CheckInf.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckInf" ],
+    [ "CheckFinite", "structopenvdb_1_1v12__1_1_1tools_1_1CheckFinite.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckFinite" ],
+    [ "CheckMagnitude", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMagnitude.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMagnitude" ],
+    [ "CheckRange", "structopenvdb_1_1v12__1_1_1tools_1_1CheckRange.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckRange" ],
+    [ "CheckMin", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMin.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMin" ],
+    [ "CheckMax", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMax.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckMax" ],
+    [ "CheckNormGrad", "structopenvdb_1_1v12__1_1_1tools_1_1CheckNormGrad.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckNormGrad" ],
+    [ "CheckEikonal", "structopenvdb_1_1v12__1_1_1tools_1_1CheckEikonal.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckEikonal" ],
+    [ "CheckDivergence", "structopenvdb_1_1v12__1_1_1tools_1_1CheckDivergence.html", "structopenvdb_1_1v12__1_1_1tools_1_1CheckDivergence" ],
+    [ "Diagnose", "classopenvdb_1_1v12__1_1_1tools_1_1Diagnose.html", "classopenvdb_1_1v12__1_1_1tools_1_1Diagnose" ],
+    [ "CheckLevelSet", "classopenvdb_1_1v12__1_1_1tools_1_1CheckLevelSet.html", "classopenvdb_1_1v12__1_1_1tools_1_1CheckLevelSet" ],
+    [ "CheckFogVolume", "classopenvdb_1_1v12__1_1_1tools_1_1CheckFogVolume.html", "classopenvdb_1_1v12__1_1_1tools_1_1CheckFogVolume" ],
     [ "FastSweeping", "classopenvdb_1_1v12__1_1_1tools_1_1FastSweeping.html", "classopenvdb_1_1v12__1_1_1tools_1_1FastSweeping" ],
-    [ "Film", "classopenvdb_1_1v12__1_1_1tools_1_1Film.html", "classopenvdb_1_1v12__1_1_1tools_1_1Film" ],
     [ "Filter", "classopenvdb_1_1v12__1_1_1tools_1_1Filter.html", "classopenvdb_1_1v12__1_1_1tools_1_1Filter" ],
+    [ "TileData", "structopenvdb_1_1v12__1_1_1tools_1_1TileData.html", "structopenvdb_1_1v12__1_1_1tools_1_1TileData" ],
     [ "FindActiveValues", "classopenvdb_1_1v12__1_1_1tools_1_1FindActiveValues.html", "classopenvdb_1_1v12__1_1_1tools_1_1FindActiveValues" ],
+    [ "VectorToScalarConverter", "structopenvdb_1_1v12__1_1_1tools_1_1VectorToScalarConverter.html", "structopenvdb_1_1v12__1_1_1tools_1_1VectorToScalarConverter" ],
+    [ "ScalarToVectorConverter", "structopenvdb_1_1v12__1_1_1tools_1_1ScalarToVectorConverter.html", "structopenvdb_1_1v12__1_1_1tools_1_1ScalarToVectorConverter" ],
+    [ "Cpt", "classopenvdb_1_1v12__1_1_1tools_1_1Cpt.html", "classopenvdb_1_1v12__1_1_1tools_1_1Cpt" ],
+    [ "Curl", "classopenvdb_1_1v12__1_1_1tools_1_1Curl.html", "classopenvdb_1_1v12__1_1_1tools_1_1Curl" ],
+    [ "Divergence", "classopenvdb_1_1v12__1_1_1tools_1_1Divergence.html", "classopenvdb_1_1v12__1_1_1tools_1_1Divergence" ],
     [ "Gradient", "classopenvdb_1_1v12__1_1_1tools_1_1Gradient.html", "classopenvdb_1_1v12__1_1_1tools_1_1Gradient" ],
-    [ "GridResampler", "classopenvdb_1_1v12__1_1_1tools_1_1GridResampler.html", "classopenvdb_1_1v12__1_1_1tools_1_1GridResampler" ],
-    [ "GridSampler", "classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html", "classopenvdb_1_1v12__1_1_1tools_1_1GridSampler" ],
-    [ "GridSampler< tree::ValueAccessor< TreeT >, SamplerType >", "classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4" ],
-    [ "GridTransformer", "classopenvdb_1_1v12__1_1_1tools_1_1GridTransformer.html", "classopenvdb_1_1v12__1_1_1tools_1_1GridTransformer" ],
-    [ "HalfWidthOp", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp" ],
-    [ "HalfWidthOp< bool >", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp_3_01bool_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp_3_01bool_01_4" ],
-    [ "HomogeneousMatMul", "structopenvdb_1_1v12__1_1_1tools_1_1HomogeneousMatMul.html", "structopenvdb_1_1v12__1_1_1tools_1_1HomogeneousMatMul" ],
-    [ "InactivePruneOp", "classopenvdb_1_1v12__1_1_1tools_1_1InactivePruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1InactivePruneOp" ],
     [ "Laplacian", "classopenvdb_1_1v12__1_1_1tools_1_1Laplacian.html", "classopenvdb_1_1v12__1_1_1tools_1_1Laplacian" ],
+    [ "MeanCurvature", "classopenvdb_1_1v12__1_1_1tools_1_1MeanCurvature.html", "classopenvdb_1_1v12__1_1_1tools_1_1MeanCurvature" ],
+    [ "Magnitude", "classopenvdb_1_1v12__1_1_1tools_1_1Magnitude.html", "classopenvdb_1_1v12__1_1_1tools_1_1Magnitude" ],
+    [ "Normalize", "classopenvdb_1_1v12__1_1_1tools_1_1Normalize.html", "classopenvdb_1_1v12__1_1_1tools_1_1Normalize" ],
+    [ "GridResampler", "classopenvdb_1_1v12__1_1_1tools_1_1GridResampler.html", "classopenvdb_1_1v12__1_1_1tools_1_1GridResampler" ],
+    [ "GridTransformer", "classopenvdb_1_1v12__1_1_1tools_1_1GridTransformer.html", "classopenvdb_1_1v12__1_1_1tools_1_1GridTransformer" ],
+    [ "ABTransform", "classopenvdb_1_1v12__1_1_1tools_1_1ABTransform.html", "classopenvdb_1_1v12__1_1_1tools_1_1ABTransform" ],
+    [ "HalfWidthOp", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp" ],
+    [ "HalfWidthOp&lt; bool &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp_3_01bool_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1HalfWidthOp_3_01bool_01_4" ],
+    [ "Sampler", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler" ],
+    [ "PointSampler", "structopenvdb_1_1v12__1_1_1tools_1_1PointSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1PointSampler" ],
+    [ "BoxSampler", "structopenvdb_1_1v12__1_1_1tools_1_1BoxSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1BoxSampler" ],
+    [ "QuadraticSampler", "structopenvdb_1_1v12__1_1_1tools_1_1QuadraticSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1QuadraticSampler" ],
+    [ "StaggeredPointSampler", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredPointSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredPointSampler" ],
+    [ "StaggeredBoxSampler", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredBoxSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredBoxSampler" ],
+    [ "StaggeredQuadraticSampler", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredQuadraticSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredQuadraticSampler" ],
+    [ "GridSampler", "classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html", "classopenvdb_1_1v12__1_1_1tools_1_1GridSampler" ],
+    [ "GridSampler&lt; tree::ValueAccessor&lt; TreeT &gt;, SamplerType &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4" ],
+    [ "DualGridSampler", "classopenvdb_1_1v12__1_1_1tools_1_1DualGridSampler.html", "classopenvdb_1_1v12__1_1_1tools_1_1DualGridSampler" ],
+    [ "DualGridSampler&lt; tree::ValueAccessor&lt; TreeT &gt;, SamplerT &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1DualGridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerT_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1DualGridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerT_01_4" ],
+    [ "AlphaMask", "classopenvdb_1_1v12__1_1_1tools_1_1AlphaMask.html", "classopenvdb_1_1v12__1_1_1tools_1_1AlphaMask" ],
+    [ "Sampler&lt; 0, false &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_010_00_01false_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_010_00_01false_01_4" ],
+    [ "Sampler&lt; 1, false &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_011_00_01false_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_011_00_01false_01_4" ],
+    [ "Sampler&lt; 2, false &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_012_00_01false_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_012_00_01false_01_4" ],
+    [ "Sampler&lt; 0, true &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_010_00_01true_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_010_00_01true_01_4" ],
+    [ "Sampler&lt; 1, true &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_011_00_01true_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_011_00_01true_01_4" ],
+    [ "Sampler&lt; 2, true &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_012_00_01true_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_012_00_01true_01_4" ],
     [ "LevelSetAdvection", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetAdvection.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetAdvection" ],
     [ "LevelSetFilter", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter" ],
     [ "LevelSetFracture", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture" ],
+    [ "DiracDelta", "classopenvdb_1_1v12__1_1_1tools_1_1DiracDelta.html", "classopenvdb_1_1v12__1_1_1tools_1_1DiracDelta" ],
     [ "LevelSetMeasure", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure" ],
     [ "LevelSetMorphing", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMorphing.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMorphing" ],
-    [ "LevelSetPruneOp", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetPruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetPruneOp" ],
-    [ "LevelSetRayIntersector", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetRayIntersector.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetRayIntersector" ],
-    [ "LevelSetRayTracer", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetRayTracer.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetRayTracer" ],
     [ "LevelSetSphere", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetSphere.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetSphere" ],
     [ "LevelSetTracker", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetTracker.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetTracker" ],
-    [ "LinearSearchImpl", "classopenvdb_1_1v12__1_1_1tools_1_1LinearSearchImpl.html", "classopenvdb_1_1v12__1_1_1tools_1_1LinearSearchImpl" ],
-    [ "Magnitude", "classopenvdb_1_1v12__1_1_1tools_1_1Magnitude.html", "classopenvdb_1_1v12__1_1_1tools_1_1Magnitude" ],
-    [ "MatMul", "structopenvdb_1_1v12__1_1_1tools_1_1MatMul.html", "structopenvdb_1_1v12__1_1_1tools_1_1MatMul" ],
-    [ "MatMulNormalize", "structopenvdb_1_1v12__1_1_1tools_1_1MatMulNormalize.html", "structopenvdb_1_1v12__1_1_1tools_1_1MatMulNormalize" ],
-    [ "MatteShader", "classopenvdb_1_1v12__1_1_1tools_1_1MatteShader.html", "classopenvdb_1_1v12__1_1_1tools_1_1MatteShader" ],
-    [ "MatteShader< Film::RGBA, SamplerType >", "classopenvdb_1_1v12__1_1_1tools_1_1MatteShader_3_01Film_1_1RGBA_00_01SamplerType_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1MatteShader_3_01Film_1_1RGBA_00_01SamplerType_01_4" ],
-    [ "MeanCurvature", "classopenvdb_1_1v12__1_1_1tools_1_1MeanCurvature.html", "classopenvdb_1_1v12__1_1_1tools_1_1MeanCurvature" ],
+    [ "TreeToMerge", "structopenvdb_1_1v12__1_1_1tools_1_1TreeToMerge.html", "structopenvdb_1_1v12__1_1_1tools_1_1TreeToMerge" ],
+    [ "CsgUnionOrIntersectionOp", "structopenvdb_1_1v12__1_1_1tools_1_1CsgUnionOrIntersectionOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1CsgUnionOrIntersectionOp" ],
+    [ "CsgDifferenceOp", "structopenvdb_1_1v12__1_1_1tools_1_1CsgDifferenceOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1CsgDifferenceOp" ],
+    [ "SumMergeOp", "structopenvdb_1_1v12__1_1_1tools_1_1SumMergeOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1SumMergeOp" ],
+    [ "QuadAndTriangleDataAdapter", "structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter.html", "structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter" ],
     [ "MeshToVoxelEdgeData", "classopenvdb_1_1v12__1_1_1tools_1_1MeshToVoxelEdgeData.html", "classopenvdb_1_1v12__1_1_1tools_1_1MeshToVoxelEdgeData" ],
     [ "MultiResGrid", "classopenvdb_1_1v12__1_1_1tools_1_1MultiResGrid.html", "classopenvdb_1_1v12__1_1_1tools_1_1MultiResGrid" ],
-    [ "NonUniformPointScatter", "classopenvdb_1_1v12__1_1_1tools_1_1NonUniformPointScatter.html", "classopenvdb_1_1v12__1_1_1tools_1_1NonUniformPointScatter" ],
-    [ "Normalize", "classopenvdb_1_1v12__1_1_1tools_1_1Normalize.html", "classopenvdb_1_1v12__1_1_1tools_1_1Normalize" ],
-    [ "NormalShader", "classopenvdb_1_1v12__1_1_1tools_1_1NormalShader.html", "classopenvdb_1_1v12__1_1_1tools_1_1NormalShader" ],
-    [ "NormalShader< Film::RGBA, SamplerType >", "classopenvdb_1_1v12__1_1_1tools_1_1NormalShader_3_01Film_1_1RGBA_00_01SamplerType_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1NormalShader_3_01Film_1_1RGBA_00_01SamplerType_01_4" ],
-    [ "OrthographicCamera", "classopenvdb_1_1v12__1_1_1tools_1_1OrthographicCamera.html", "classopenvdb_1_1v12__1_1_1tools_1_1OrthographicCamera" ],
+    [ "DepthFirstNodeVisitor", "structopenvdb_1_1v12__1_1_1tools_1_1DepthFirstNodeVisitor.html", "structopenvdb_1_1v12__1_1_1tools_1_1DepthFirstNodeVisitor" ],
+    [ "DepthFirstNodeVisitor&lt; NodeT, 0 &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1DepthFirstNodeVisitor_3_01NodeT_00_010_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1DepthFirstNodeVisitor_3_01NodeT_00_010_01_4" ],
     [ "ParticleAtlas", "structopenvdb_1_1v12__1_1_1tools_1_1ParticleAtlas.html", "structopenvdb_1_1v12__1_1_1tools_1_1ParticleAtlas" ],
     [ "ParticlesToLevelSet", "classopenvdb_1_1v12__1_1_1tools_1_1ParticlesToLevelSet.html", "classopenvdb_1_1v12__1_1_1tools_1_1ParticlesToLevelSet" ],
-    [ "PerspectiveCamera", "classopenvdb_1_1v12__1_1_1tools_1_1PerspectiveCamera.html", "classopenvdb_1_1v12__1_1_1tools_1_1PerspectiveCamera" ],
+    [ "ClosestPointProjector", "classopenvdb_1_1v12__1_1_1tools_1_1ClosestPointProjector.html", "classopenvdb_1_1v12__1_1_1tools_1_1ClosestPointProjector" ],
     [ "PointAdvect", "classopenvdb_1_1v12__1_1_1tools_1_1PointAdvect.html", "classopenvdb_1_1v12__1_1_1tools_1_1PointAdvect" ],
-    [ "PointIndexFilter", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexFilter.html", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexFilter" ],
-    [ "PointIndexIterator", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexIterator.html", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexIterator" ],
+    [ "ConstrainedPointAdvect", "classopenvdb_1_1v12__1_1_1tools_1_1ConstrainedPointAdvect.html", "classopenvdb_1_1v12__1_1_1tools_1_1ConstrainedPointAdvect" ],
     [ "PointIndexLeafNode", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode" ],
+    [ "PointIndexIterator", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexIterator.html", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexIterator" ],
+    [ "PointIndexFilter", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexFilter.html", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexFilter" ],
     [ "PointPartitioner", "classopenvdb_1_1v12__1_1_1tools_1_1PointPartitioner.html", "classopenvdb_1_1v12__1_1_1tools_1_1PointPartitioner" ],
-    [ "PointSampler", "structopenvdb_1_1v12__1_1_1tools_1_1PointSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1PointSampler" ],
-    [ "PointsToMask", "classopenvdb_1_1v12__1_1_1tools_1_1PointsToMask.html", "classopenvdb_1_1v12__1_1_1tools_1_1PointsToMask" ],
-    [ "PolygonPool", "classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool.html", "classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool" ],
-    [ "PositionShader", "classopenvdb_1_1v12__1_1_1tools_1_1PositionShader.html", "classopenvdb_1_1v12__1_1_1tools_1_1PositionShader" ],
-    [ "PositionShader< Film::RGBA, SamplerType >", "classopenvdb_1_1v12__1_1_1tools_1_1PositionShader_3_01Film_1_1RGBA_00_01SamplerType_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1PositionShader_3_01Film_1_1RGBA_00_01SamplerType_01_4" ],
-    [ "QuadAndTriangleDataAdapter", "structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter.html", "structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter" ],
-    [ "QuadraticSampler", "structopenvdb_1_1v12__1_1_1tools_1_1QuadraticSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1QuadraticSampler" ],
-    [ "Sampler", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler" ],
-    [ "Sampler< 0, false >", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_010_00_01false_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_010_00_01false_01_4" ],
-    [ "Sampler< 0, true >", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_010_00_01true_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_010_00_01true_01_4" ],
-    [ "Sampler< 1, false >", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_011_00_01false_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_011_00_01false_01_4" ],
-    [ "Sampler< 1, true >", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_011_00_01true_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_011_00_01true_01_4" ],
-    [ "Sampler< 2, false >", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_012_00_01false_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_012_00_01false_01_4" ],
-    [ "Sampler< 2, true >", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_012_00_01true_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1Sampler_3_012_00_01true_01_4" ],
-    [ "ScalarToVectorConverter", "structopenvdb_1_1v12__1_1_1tools_1_1ScalarToVectorConverter.html", "structopenvdb_1_1v12__1_1_1tools_1_1ScalarToVectorConverter" ],
-    [ "SignedFloodFillOp", "classopenvdb_1_1v12__1_1_1tools_1_1SignedFloodFillOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1SignedFloodFillOp" ],
-    [ "SparseExtractor", "classopenvdb_1_1v12__1_1_1tools_1_1SparseExtractor.html", "classopenvdb_1_1v12__1_1_1tools_1_1SparseExtractor" ],
-    [ "SparseMaskedExtractor", "classopenvdb_1_1v12__1_1_1tools_1_1SparseMaskedExtractor.html", "classopenvdb_1_1v12__1_1_1tools_1_1SparseMaskedExtractor" ],
-    [ "SparseToDenseCompositor", "classopenvdb_1_1v12__1_1_1tools_1_1SparseToDenseCompositor.html", "classopenvdb_1_1v12__1_1_1tools_1_1SparseToDenseCompositor" ],
-    [ "StaggeredBoxSampler", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredBoxSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredBoxSampler" ],
-    [ "StaggeredPointSampler", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredPointSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredPointSampler" ],
-    [ "StaggeredQuadraticSampler", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredQuadraticSampler.html", "structopenvdb_1_1v12__1_1_1tools_1_1StaggeredQuadraticSampler" ],
-    [ "SumMergeOp", "structopenvdb_1_1v12__1_1_1tools_1_1SumMergeOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1SumMergeOp" ],
-    [ "TileData", "structopenvdb_1_1v12__1_1_1tools_1_1TileData.html", "structopenvdb_1_1v12__1_1_1tools_1_1TileData" ],
-    [ "TolerancePruneOp", "classopenvdb_1_1v12__1_1_1tools_1_1TolerancePruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1TolerancePruneOp" ],
-    [ "TreeToMerge", "structopenvdb_1_1v12__1_1_1tools_1_1TreeToMerge.html", "structopenvdb_1_1v12__1_1_1tools_1_1TreeToMerge" ],
+    [ "BasePointScatter", "classopenvdb_1_1v12__1_1_1tools_1_1BasePointScatter.html", "classopenvdb_1_1v12__1_1_1tools_1_1BasePointScatter" ],
     [ "UniformPointScatter", "classopenvdb_1_1v12__1_1_1tools_1_1UniformPointScatter.html", "classopenvdb_1_1v12__1_1_1tools_1_1UniformPointScatter" ],
-    [ "VectorToScalarConverter", "structopenvdb_1_1v12__1_1_1tools_1_1VectorToScalarConverter.html", "structopenvdb_1_1v12__1_1_1tools_1_1VectorToScalarConverter" ],
+    [ "DenseUniformPointScatter", "classopenvdb_1_1v12__1_1_1tools_1_1DenseUniformPointScatter.html", "classopenvdb_1_1v12__1_1_1tools_1_1DenseUniformPointScatter" ],
+    [ "NonUniformPointScatter", "classopenvdb_1_1v12__1_1_1tools_1_1NonUniformPointScatter.html", "classopenvdb_1_1v12__1_1_1tools_1_1NonUniformPointScatter" ],
+    [ "PointsToMask", "classopenvdb_1_1v12__1_1_1tools_1_1PointsToMask.html", "classopenvdb_1_1v12__1_1_1tools_1_1PointsToMask" ],
     [ "VectorToScalarGrid", "structopenvdb_1_1v12__1_1_1tools_1_1VectorToScalarGrid.html", "structopenvdb_1_1v12__1_1_1tools_1_1VectorToScalarGrid" ],
-    [ "VelocityIntegrator", "classopenvdb_1_1v12__1_1_1tools_1_1VelocityIntegrator.html", "classopenvdb_1_1v12__1_1_1tools_1_1VelocityIntegrator" ],
-    [ "VelocitySampler", "classopenvdb_1_1v12__1_1_1tools_1_1VelocitySampler.html", "classopenvdb_1_1v12__1_1_1tools_1_1VelocitySampler" ],
-    [ "VolumeAdvection", "classopenvdb_1_1v12__1_1_1tools_1_1VolumeAdvection.html", "classopenvdb_1_1v12__1_1_1tools_1_1VolumeAdvection" ],
+    [ "InactivePruneOp", "classopenvdb_1_1v12__1_1_1tools_1_1InactivePruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1InactivePruneOp" ],
+    [ "TolerancePruneOp", "classopenvdb_1_1v12__1_1_1tools_1_1TolerancePruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1TolerancePruneOp" ],
+    [ "LevelSetPruneOp", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetPruneOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetPruneOp" ],
+    [ "LinearSearchImpl", "classopenvdb_1_1v12__1_1_1tools_1_1LinearSearchImpl.html", "classopenvdb_1_1v12__1_1_1tools_1_1LinearSearchImpl" ],
+    [ "LevelSetRayIntersector", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetRayIntersector.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetRayIntersector" ],
     [ "VolumeRayIntersector", "classopenvdb_1_1v12__1_1_1tools_1_1VolumeRayIntersector.html", "classopenvdb_1_1v12__1_1_1tools_1_1VolumeRayIntersector" ],
+    [ "LevelSetRayTracer", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetRayTracer.html", "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetRayTracer" ],
     [ "VolumeRender", "classopenvdb_1_1v12__1_1_1tools_1_1VolumeRender.html", "classopenvdb_1_1v12__1_1_1tools_1_1VolumeRender" ],
+    [ "Film", "classopenvdb_1_1v12__1_1_1tools_1_1Film.html", "classopenvdb_1_1v12__1_1_1tools_1_1Film" ],
+    [ "BaseCamera", "classopenvdb_1_1v12__1_1_1tools_1_1BaseCamera.html", "classopenvdb_1_1v12__1_1_1tools_1_1BaseCamera" ],
+    [ "PerspectiveCamera", "classopenvdb_1_1v12__1_1_1tools_1_1PerspectiveCamera.html", "classopenvdb_1_1v12__1_1_1tools_1_1PerspectiveCamera" ],
+    [ "OrthographicCamera", "classopenvdb_1_1v12__1_1_1tools_1_1OrthographicCamera.html", "classopenvdb_1_1v12__1_1_1tools_1_1OrthographicCamera" ],
+    [ "BaseShader", "classopenvdb_1_1v12__1_1_1tools_1_1BaseShader.html", "classopenvdb_1_1v12__1_1_1tools_1_1BaseShader" ],
+    [ "MatteShader", "classopenvdb_1_1v12__1_1_1tools_1_1MatteShader.html", "classopenvdb_1_1v12__1_1_1tools_1_1MatteShader" ],
+    [ "MatteShader&lt; Film::RGBA, SamplerType &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1MatteShader_3_01Film_1_1RGBA_00_01SamplerType_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1MatteShader_3_01Film_1_1RGBA_00_01SamplerType_01_4" ],
+    [ "NormalShader", "classopenvdb_1_1v12__1_1_1tools_1_1NormalShader.html", "classopenvdb_1_1v12__1_1_1tools_1_1NormalShader" ],
+    [ "NormalShader&lt; Film::RGBA, SamplerType &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1NormalShader_3_01Film_1_1RGBA_00_01SamplerType_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1NormalShader_3_01Film_1_1RGBA_00_01SamplerType_01_4" ],
+    [ "PositionShader", "classopenvdb_1_1v12__1_1_1tools_1_1PositionShader.html", "classopenvdb_1_1v12__1_1_1tools_1_1PositionShader" ],
+    [ "PositionShader&lt; Film::RGBA, SamplerType &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1PositionShader_3_01Film_1_1RGBA_00_01SamplerType_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1PositionShader_3_01Film_1_1RGBA_00_01SamplerType_01_4" ],
+    [ "DiffuseShader", "classopenvdb_1_1v12__1_1_1tools_1_1DiffuseShader.html", "classopenvdb_1_1v12__1_1_1tools_1_1DiffuseShader" ],
+    [ "DiffuseShader&lt; Film::RGBA, SamplerType &gt;", "classopenvdb_1_1v12__1_1_1tools_1_1DiffuseShader_3_01Film_1_1RGBA_00_01SamplerType_01_4.html", "classopenvdb_1_1v12__1_1_1tools_1_1DiffuseShader_3_01Film_1_1RGBA_00_01SamplerType_01_4" ],
+    [ "SignedFloodFillOp", "classopenvdb_1_1v12__1_1_1tools_1_1SignedFloodFillOp.html", "classopenvdb_1_1v12__1_1_1tools_1_1SignedFloodFillOp" ],
+    [ "HomogeneousMatMul", "structopenvdb_1_1v12__1_1_1tools_1_1HomogeneousMatMul.html", "structopenvdb_1_1v12__1_1_1tools_1_1HomogeneousMatMul" ],
+    [ "MatMul", "structopenvdb_1_1v12__1_1_1tools_1_1MatMul.html", "structopenvdb_1_1v12__1_1_1tools_1_1MatMul" ],
+    [ "MatMulNormalize", "structopenvdb_1_1v12__1_1_1tools_1_1MatMulNormalize.html", "structopenvdb_1_1v12__1_1_1tools_1_1MatMulNormalize" ],
+    [ "DiscreteField", "classopenvdb_1_1v12__1_1_1tools_1_1DiscreteField.html", "classopenvdb_1_1v12__1_1_1tools_1_1DiscreteField" ],
+    [ "EnrightField", "classopenvdb_1_1v12__1_1_1tools_1_1EnrightField.html", "classopenvdb_1_1v12__1_1_1tools_1_1EnrightField" ],
+    [ "VelocitySampler", "classopenvdb_1_1v12__1_1_1tools_1_1VelocitySampler.html", "classopenvdb_1_1v12__1_1_1tools_1_1VelocitySampler" ],
+    [ "VelocityIntegrator", "classopenvdb_1_1v12__1_1_1tools_1_1VelocityIntegrator.html", "classopenvdb_1_1v12__1_1_1tools_1_1VelocityIntegrator" ],
+    [ "VolumeAdvection", "classopenvdb_1_1v12__1_1_1tools_1_1VolumeAdvection.html", "classopenvdb_1_1v12__1_1_1tools_1_1VolumeAdvection" ],
+    [ "PolygonPool", "classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool.html", "classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool" ],
     [ "VolumeToMesh", "structopenvdb_1_1v12__1_1_1tools_1_1VolumeToMesh.html", "structopenvdb_1_1v12__1_1_1tools_1_1VolumeToMesh" ],
+    [ "ClosestSurfacePoint", "classopenvdb_1_1v12__1_1_1tools_1_1ClosestSurfacePoint.html", "classopenvdb_1_1v12__1_1_1tools_1_1ClosestSurfacePoint" ],
+    [ "ConvexVoxelizer", "classopenvdb_1_1v12__1_1_1tools_1_1ConvexVoxelizer.html", "classopenvdb_1_1v12__1_1_1tools_1_1ConvexVoxelizer" ],
     [ "CsgIntersectionOp", "namespaceopenvdb_1_1v12__1_1_1tools.html#a15acb14744ad597506ab2c876df1e3c0", null ],
     [ "CsgUnionOp", "namespaceopenvdb_1_1v12__1_1_1tools.html#aa2bd678647ee7c097628900599ecd911", null ],
     [ "OutTreeT", "namespaceopenvdb_1_1v12__1_1_1tools.html#aaf47d705ae442538657c031fb9dce3c5", null ],
