@@ -1,7 +1,7 @@
 var nanovdb_2nanovdb_2NodeManager_8h =
 [
     [ "NodeManagerData", "structnanovdb_1_1NodeManagerData.html", "structnanovdb_1_1NodeManagerData" ],
-    [ "NodeManagerHandle< BufferT >", "classnanovdb_1_1NodeManagerHandle.html", "classnanovdb_1_1NodeManagerHandle" ],
-    [ "NodeManager< BuildT >", "classnanovdb_1_1NodeManager.html", "classnanovdb_1_1NodeManager" ],
+    [ "NodeManagerHandle&lt; BufferT &gt;", "classnanovdb_1_1NodeManagerHandle.html", "classnanovdb_1_1NodeManagerHandle" ],
+    [ "NodeManager&lt; BuildT &gt;", "classnanovdb_1_1NodeManager.html", "classnanovdb_1_1NodeManager" ],
     [ "nanovdb::createNodeManager", "namespacenanovdb.html#aefce754e1e7397fb6d1a75c1eec1054b", null ]
 ];
\ No newline at end of file
