@@ -9,30 +9,19 @@ var NAVTREEINDEX1 =
 "HDDA_8h_source.html":[16,0,1,2,8],
 "Half_8h.html":[16,0,2,1,5],
 "Half_8h.html#a008b5ce140070218111dd91cd20c7f6a":[16,0,2,1,5,4],
-"Half_8h.html#a0a7c1f2cebb5360e2c75f8e72ebb0bb1":[16,0,2,1,5,18],
 "Half_8h.html#a12109d0a04de04b6a9fa5d4d71505e3b":[16,0,2,1,5,8],
-"Half_8h.html#a34429af29cd22692a1c9da407daf95a6":[16,0,2,1,5,27],
-"Half_8h.html#a3479647da2cee29c3bf33494ab62a235":[16,0,2,1,5,25],
-"Half_8h.html#a3cf74784c4dde4c1610a607afd574b8b":[16,0,2,1,5,26],
 "Half_8h.html#a400bf15484040c8b11bdd6662764685e":[16,0,2,1,5,9],
-"Half_8h.html#a61b94d436edf43cb65c17bd9261495b4":[16,0,2,1,5,19],
 "Half_8h.html#a6434f3c1f1a7d61051a11d5d63e6c026":[16,0,2,1,5,12],
 "Half_8h.html#a69fc8e8fe0b81f9ec2021101ff170b27":[16,0,2,1,5,16],
 "Half_8h.html#a6a3efa8ea0176dcef0f7b9138338f337":[16,0,2,1,5,5],
 "Half_8h.html#a6cb440be2fe914c23181beee004446b0":[16,0,2,1,5,11],
 "Half_8h.html#a72d304ed26e0076c7ca6e9beed52a2f2":[16,0,2,1,5,15],
 "Half_8h.html#a78e9d88a54bcf343ebdece9711e6bf70":[16,0,2,1,5,3],
-"Half_8h.html#a7af21f412cb5dec9c744263fbc80d326":[16,0,2,1,5,20],
-"Half_8h.html#a9c73f179185e8199f16aa5ccbfdb7e75":[16,0,2,1,5,17],
 "Half_8h.html#aad9bd971f305c5ae8b61a5ccc703dabb":[16,0,2,1,5,14],
 "Half_8h.html#ab2a99437b22c67be39fcf40ef8eb61b8":[16,0,2,1,5,10],
 "Half_8h.html#ab399ae7beba45bba48fe89c5d90add3b":[16,0,2,1,5,13],
 "Half_8h.html#ab829ca4cdadecf0abf5f4585f065283e":[16,0,2,1,5,6],
-"Half_8h.html#ab922cde65d0eecc74c48607af60fded0":[16,0,2,1,5,23],
 "Half_8h.html#ace1176eea441f8ded55f7383eec35f6f":[16,0,2,1,5,7],
-"Half_8h.html#ade2182eee05a8ed9a84eec2866f0e41b":[16,0,2,1,5,21],
-"Half_8h.html#ae18dc0e4cc0fa95abd6bca8dd47bc8d3":[16,0,2,1,5,24],
-"Half_8h.html#aedd7fa37e5d01d73c4b23591eeca49cd":[16,0,2,1,5,22],
 "Half_8h_source.html":[16,0,2,1,5],
 "HostBuffer_8h.html":[16,0,1,5],
 "HostBuffer_8h.html#aff2830fced928188855df8b9366e031f":[16,0,1,5,3],
@@ -133,26 +122,26 @@ var NAVTREEINDEX1 =
 "NanoToOpenVDB_8h.html":[16,0,1,2,13],
 "NanoToOpenVDB_8h_source.html":[16,0,1,2,13],
 "NanoVDB_8h.html":[16,0,1,6],
-"NanoVDB_8h.html#a01604c4a002e700cf39c3c3a2dc2eb5c":[16,0,1,6,123],
-"NanoVDB_8h.html#a07ef91a6ad762e2e320f2032c2249c63":[16,0,1,6,124],
-"NanoVDB_8h.html#a27c1f0f2bf7b8fe1c8fed953677d08ae":[16,0,1,6,126],
-"NanoVDB_8h.html#a36c9da50c4e9e9e1cd4180921f0a0ab2":[16,0,1,6,125],
-"NanoVDB_8h.html#a3ac48c8766ed12e2d673a9f3809365e1":[16,0,1,6,129],
-"NanoVDB_8h.html#a4af192d64f30b1b6bda1a3e6ba93df11":[16,0,1,6,132],
-"NanoVDB_8h.html#a4f8b26821816e0334dfd79e0cbd39c4d":[16,0,1,6,121],
-"NanoVDB_8h.html#a54db29617e4e954de4af9721a183f789":[16,0,1,6,122],
-"NanoVDB_8h.html#a5c3e462d9f4cf1358ad8fda5d34b0ab1":[16,0,1,6,128],
-"NanoVDB_8h.html#a7f41130cb850d9fcf11ba3a25c35ee6d":[16,0,1,6,133],
-"NanoVDB_8h.html#a8cf1f4b7936a9ad6e92358dc22b48a79":[16,0,1,6,131],
-"NanoVDB_8h.html#a990442e1e831eb77440c51eafeda90b5":[16,0,1,6,127],
-"NanoVDB_8h.html#ab7ea3d375035a51f6e536b6f496dda64":[16,0,1,6,130],
+"NanoVDB_8h.html#a01604c4a002e700cf39c3c3a2dc2eb5c":[16,0,1,6,124],
+"NanoVDB_8h.html#a07ef91a6ad762e2e320f2032c2249c63":[16,0,1,6,125],
+"NanoVDB_8h.html#a27c1f0f2bf7b8fe1c8fed953677d08ae":[16,0,1,6,127],
+"NanoVDB_8h.html#a36c9da50c4e9e9e1cd4180921f0a0ab2":[16,0,1,6,126],
+"NanoVDB_8h.html#a3ac48c8766ed12e2d673a9f3809365e1":[16,0,1,6,130],
+"NanoVDB_8h.html#a4af192d64f30b1b6bda1a3e6ba93df11":[16,0,1,6,133],
+"NanoVDB_8h.html#a4f8b26821816e0334dfd79e0cbd39c4d":[16,0,1,6,122],
+"NanoVDB_8h.html#a54db29617e4e954de4af9721a183f789":[16,0,1,6,123],
+"NanoVDB_8h.html#a5c3e462d9f4cf1358ad8fda5d34b0ab1":[16,0,1,6,129],
+"NanoVDB_8h.html#a7f41130cb850d9fcf11ba3a25c35ee6d":[16,0,1,6,134],
+"NanoVDB_8h.html#a8cf1f4b7936a9ad6e92358dc22b48a79":[16,0,1,6,132],
+"NanoVDB_8h.html#a990442e1e831eb77440c51eafeda90b5":[16,0,1,6,128],
+"NanoVDB_8h.html#ab7ea3d375035a51f6e536b6f496dda64":[16,0,1,6,131],
 "NanoVDB_8h_source.html":[16,0,1,6],
 "NanoVDB_FAQ.html":[11,1],
 "NanoVDB_HelloWorld.html":[11,3],
 "NanoVDB_HowToBuild.html":[11,0],
-"NanoVDB_HowToBuild.html#autotoc_md7":[11,0,0],
-"NanoVDB_HowToBuild.html#autotoc_md8":[11,0,1],
-"NanoVDB_HowToBuild.html#autotoc_md9":[11,0,2],
+"NanoVDB_HowToBuild.html#autotoc_md5":[11,0,0],
+"NanoVDB_HowToBuild.html#autotoc_md6":[11,0,1],
+"NanoVDB_HowToBuild.html#autotoc_md7":[11,0,2],
 "NanoVDB_MainPage.html":[11],
 "NanoVDB_SourceTree.html":[11,2],
 "NodeMasks_8h.html":[16,0,2,5,7],
@@ -249,5 +238,16 @@ var NAVTREEINDEX1 =
 "PNanoVDB_8h.html#a2d9a3f37c4620c3258e0aa6f4c1f72c3":[16,0,1,8,296],
 "PNanoVDB_8h.html#a2dacb416b5363ce699084f1a9ac4ab89":[16,0,1,8,410],
 "PNanoVDB_8h.html#a2e910334142d89066e31b7353d98b6fb":[16,0,1,8,352],
-"PNanoVDB_8h.html#a2f12d8941f2acfb6675ed3e9412c82b8":[16,0,1,8,81]
+"PNanoVDB_8h.html#a2f12d8941f2acfb6675ed3e9412c82b8":[16,0,1,8,81],
+"PNanoVDB_8h.html#a3026d38d82c70cf05d2a9da463cb443d":[16,0,1,8,43],
+"PNanoVDB_8h.html#a302ae676b0f9d3bd7a5cb5f94652e293":[16,0,1,8,421],
+"PNanoVDB_8h.html#a30a7aa0b06b11a75ff2e17b7551721d6":[16,0,1,8,292],
+"PNanoVDB_8h.html#a31c11064df154523bf79eee759dd940d":[16,0,1,8,416],
+"PNanoVDB_8h.html#a3221983e947c00e924d2eff222de175f":[16,0,1,8,286],
+"PNanoVDB_8h.html#a3270fa69771374e7631a18c419fdef52":[16,0,1,8,308],
+"PNanoVDB_8h.html#a32b0141b6d44f0ac7200dc1cf5fb5178":[16,0,1,8,340],
+"PNanoVDB_8h.html#a32e4c9855280981edf0be8e179df3675":[16,0,1,8,370],
+"PNanoVDB_8h.html#a33fd54373731e1fb8ebd50e04a4cf9e8":[16,0,1,8,382],
+"PNanoVDB_8h.html#a341b73ff7a887fc4a79b8e4a71b96ea3":[16,0,1,8,468],
+"PNanoVDB_8h.html#a35884ec8b0408c606f24ef4b54bf0b4d":[16,0,1,8,145]
 };
