@@ -1,7 +1,7 @@
 var openvdb_2openvdb_2util_2Util_8h =
 [
-    [ "LeafTopologyIntOp< TreeType1, TreeType2 >", "classopenvdb_1_1v12__1_1_1util_1_1LeafTopologyIntOp.html", "classopenvdb_1_1v12__1_1_1util_1_1LeafTopologyIntOp" ],
-    [ "LeafTopologyDiffOp< TreeType1, TreeType2 >", "classopenvdb_1_1v12__1_1_1util_1_1LeafTopologyDiffOp.html", "classopenvdb_1_1v12__1_1_1util_1_1LeafTopologyDiffOp" ],
+    [ "LeafTopologyIntOp&lt; TreeType1, TreeType2 &gt;", "classopenvdb_1_1v12__1_1_1util_1_1LeafTopologyIntOp.html", "classopenvdb_1_1v12__1_1_1util_1_1LeafTopologyIntOp" ],
+    [ "LeafTopologyDiffOp&lt; TreeType1, TreeType2 &gt;", "classopenvdb_1_1v12__1_1_1util_1_1LeafTopologyDiffOp.html", "classopenvdb_1_1v12__1_1_1util_1_1LeafTopologyDiffOp" ],
     [ "openvdb::v12_1::util::leafTopologyDifference", "namespaceopenvdb_1_1v12__1_1_1util.html#a1c6952595283677e0135674f7789dd55", null ],
     [ "openvdb::v12_1::util::leafTopologyIntersection", "namespaceopenvdb_1_1v12__1_1_1util.html#ad8a164246b5cb74cd9871fe28c00ab8c", null ],
     [ "openvdb::v12_1::util::nearestCoord", "namespaceopenvdb_1_1v12__1_1_1util.html#a5b5e5d74f59aff1eda8912ae634ff273", null ],
