@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['qnan_0',['qNan',['../classhalf.html#a210eb05b9cb5e702cd3b98f24eea0a78',1,'half']]],
+  ['qnan_0',['qNan',['../classopenvdb_1_1v12__1_1_1math_1_1internal_1_1half.html#a210eb05b9cb5e702cd3b98f24eea0a78',1,'openvdb::v12_1::math::internal::half']]],
   ['quad_1',['quad',['../classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool.html#a55858b7ea4e93c3db5ef8d448f9c4052',1,'openvdb::v12_1::tools::PolygonPool::quad(size_t n)'],['../classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool.html#ad0b06d7be794a58f4aa1a0c2db3d439a',1,'openvdb::v12_1::tools::PolygonPool::quad(size_t n) const']]],
   ['quadandtriangledataadapter_2',['QuadAndTriangleDataAdapter',['../structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter.html',1,'QuadAndTriangleDataAdapter&lt; PointType, PolygonType &gt;'],['../structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter.html#a77132b44ec7d41809377d4bd855ba459',1,'openvdb::v12_1::tools::QuadAndTriangleDataAdapter::QuadAndTriangleDataAdapter(const std::vector&lt; PointType &gt; &amp;points, const std::vector&lt; PolygonType &gt; &amp;polygons)'],['../structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter.html#abed5272d67f448d98ffb5530a78c8040',1,'openvdb::v12_1::tools::QuadAndTriangleDataAdapter::QuadAndTriangleDataAdapter(const PointType *pointArray, size_t pointArraySize, const PolygonType *polygonArray, size_t polygonArraySize)']]],
   ['quadflags_3',['quadFlags',['../classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool.html#af9c07e03219767aa6bc426ac4f0bbfd2',1,'openvdb::v12_1::tools::PolygonPool::quadFlags(size_t n)'],['../classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool.html#a4ff27555ca6d775dc073c4a6d7b9dfec',1,'openvdb::v12_1::tools::PolygonPool::quadFlags(size_t n) const']]],
