@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['imath_5fhalf_5fuif_0',['imath_half_uif',['../unionimath__half__uif.html',1,'']]],
+  ['imath_5fhalf_5fuif_0',['imath_half_uif',['../unionopenvdb_1_1v12__1_1_1math_1_1internal_1_1imath__half__uif.html',1,'openvdb::v12_1::math::internal']]],
   ['inactivepruneop_1',['InactivePruneOp',['../classopenvdb_1_1v12__1_1_1tools_1_1InactivePruneOp.html',1,'openvdb::v12_1::tools']]],
   ['incompletecholeskypreconditioner_2',['IncompleteCholeskyPreconditioner',['../classopenvdb_1_1v12__1_1_1math_1_1pcg_1_1IncompleteCholeskyPreconditioner.html',1,'openvdb::v12_1::math::pcg']]],
   ['index_5fsequence_3',['index_sequence',['../structcxx14_1_1index__sequence.html',1,'index_sequence&lt;... &gt;'],['../structopenvdb_1_1v12__1_1_1index__sequence.html',1,'index_sequence&lt; Ns &gt;']]],
