@@ -39,7 +39,6 @@ var structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode =
     [ "addLeafAndCache", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#ae07c8f1c226898790e697735169633db", null ],
     [ "addTile", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a568b9575dfcb86feff1f8380ca957d04", null ],
     [ "addTile", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a05951fc38afd4cc77a9ae662ee1bdff4", null ],
-    [ "addTileAndCache", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a5444589513103d9ced9047f053822e06", null ],
     [ "addTileAndCache", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#adf106dbda7b0cc7ac3453cc9b2b9c7b1", null ],
     [ "allocate", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#add23d9f5bbc918076d240287a9b3664f", null ],
     [ "assertNonmodifiable", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#aa3740f7b3bf9900ebff77ec3689bb03f", null ],
@@ -71,15 +70,12 @@ var structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode =
     [ "cendValueOn", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a6340a66d1f081a9704191c9915282134", null ],
     [ "childCount", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a22ec70401397f9cb40501b0e28f6f336", null ],
     [ "clip", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#ad73237cff1ce2ebd9c629a0da397e55f", null ],
-    [ "combine", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#aeca5287485b1f5f6b60c6fe1f78ff530", null ],
     [ "combine", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a949b19d7cd86ab3945a8eb5e0f68e546", null ],
     [ "combine", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#af91591f5f0da41c8662c7cc1ece29e06", null ],
-    [ "combine2", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a47a65822b68cd058ba1737704b63470a", null ],
     [ "combine2", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#acfffe9e1e78fc6de78b890a2c2adaa44", null ],
     [ "combine2", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#aa4357e9061a929862d8624e16d6a53bd", null ],
     [ "combine2", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a71b82ba9fc3928aada4d493dec89be7d", null ],
     [ "coordToOffset", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a87e51328d0a2a73ad0bea8ba1a8c4b55", null ],
-    [ "copyFromDense", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a9c324f013ba5c6e0785e8513af13f80b", null ],
     [ "copyFromDense", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a289e54ea2a89b08bede71bf99da746e0", null ],
     [ "copyToDense", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a195825f611f78d1b10451ce535cffe79", null ],
     [ "denseFill", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#abb399cd065108e53e7b65612e74372a5", null ],
@@ -112,9 +108,9 @@ var structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode =
     [ "getNodes", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a3a3e4a15e6c8a32de9b2417d06fea2e7", null ],
     [ "getOrigin", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#ac06a6ece116cdfb833307740670a7528", null ],
     [ "getOrigin", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a07140669eff5dd86534cce2865d41a19", null ],
-    [ "getValue", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#ac11f6454daf437b14930610e0ad37291", null ],
+    [ "getValue", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a28e0d93d4b96220a761e56aef419956e", null ],
     [ "getValue", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a6d2c605404a1da658e7997f743731835", null ],
-    [ "getValue", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a559d1c2238e14a4bade73a24192596cd", null ],
+    [ "getValue", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a63a5caa119709df23c7807bf12df073b", null ],
     [ "getValueAndCache", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a6e0e2349b41f63f8fcbf8340d47b666b", null ],
     [ "getValueLevel", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a5b4a63a1f71f21814f0eb7e34aae3d32", null ],
     [ "getValueLevelAndCache", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a672670a1b80aa035e8fe6a4f430345fb", null ],
@@ -148,7 +144,7 @@ var structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode =
     [ "isValueOnAndCache", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a764d9f6528248f70fb667e91d35d7aab", null ],
     [ "leafCount", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a2784ec0a46f8d43b8e19d7e84fe9b90b", null ],
     [ "log2dim", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a93137277438fecb5b2fcd44a48628f16", null ],
-    [ "medianAll", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a59cd7ab07b93b753538a62876f2248a4", null ],
+    [ "medianAll", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a43bc3ff5831a2f1dc1a699590779d9ae", null ],
     [ "medianOff", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a3cad365f9baf2ce30c9dc20cbdcd1a58", null ],
     [ "medianOn", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a5375d3dffb3d3b3ea9149c37e55b5505", null ],
     [ "memUsage", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#ae7d5580aa0181f1610d1014563a41581", null ],
@@ -156,9 +152,7 @@ var structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode =
     [ "merge", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a13c35d9f38248d636ac40d9ac327192f", null ],
     [ "merge", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a23b8659f79e745e474113157d6813db9", null ],
     [ "merge", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a4119e466f0aaba9e53ef8b8d97af8a18", null ],
-    [ "merge", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#ac297dac860f2a8354b94a9962598e79a", null ],
     [ "merge", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#ad10d3b3839961c3f5e8138fef390dc62", null ],
-    [ "merge", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a9e20236620be1916d242a3b791473901", null ],
     [ "merge", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a9c72e2c46ffacb220cb6c1f91b4955f4", null ],
     [ "modifyValue", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#ae1d1b15ee3ea5f2e9431e84138a9a02b", null ],
     [ "modifyValue", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a3380f7ca101cd90c6b77073edecb181c", null ],
@@ -243,9 +237,7 @@ var structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode =
     [ "str", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#ae9b08fca99a89639cd78a91152a64d5f", null ],
     [ "streamingSize", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#aab3a8f1357c13224d7ac63ec633f33ef", null ],
     [ "swap", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#ab3ec926460bc5d1a80ce411498ea04ef", null ],
-    [ "topologyDifference", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#ab806ba12c5a214ace1c3637e8e1d78e2", null ],
     [ "topologyDifference", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a360f3f39eb6d02f55b36697c5b5c2d14", null ],
-    [ "topologyIntersection", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#afd489fd5603909c27a0366ad1ee3c754", null ],
     [ "topologyIntersection", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a6ea86b45ea34339f6c78389c7e61d10d", null ],
     [ "topologyUnion", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#a7c0b819b03aecc3c083b487a18155f27", null ],
     [ "touchLeaf", "structopenvdb_1_1v12__1_1_1tools_1_1PointIndexLeafNode.html#aaf8334b3271e7786a7cc792382de353d", null ],
